@@ -1,20 +1,20 @@
-/*
- * Copyright 2023 Soren Stoutner <soren@stoutner.com>.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-FileCopyrightText: 2023-2024 Soren Stoutner <soren@stoutner.com>
  *
- * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc>.
+ * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc/>.
  *
- * Privacy Browser PC is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
  *
- * Privacy Browser PC is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 // Application headers.
@@ -24,16 +24,16 @@
 const int BookmarksDatabase::SCHEMA_VERSION = 0;
 
 // Define the public static constants.
-const QString BookmarksDatabase::CONNECTION_NAME = "bookmarks_database";
-const QString BookmarksDatabase::BOOKMARK_NAME = "bookmark_name";
-const QString BookmarksDatabase::BOOKMARKS_TABLE = "bookmarks";
-const QString BookmarksDatabase::BOOKMARK_URL = "bookmark_url";
-const QString BookmarksDatabase::DISPLAY_ORDER = "display_order";
-const QString BookmarksDatabase::FAVORITE_ICON = "favorite_icon";
-const QString BookmarksDatabase::FOLDER_ID = "folder_id";
-const QString BookmarksDatabase::ID = "_id";
-const QString BookmarksDatabase::IS_FOLDER = "is_folder";
-const QString BookmarksDatabase::PARENT_FOLDER_ID = "parent_folder_id";
+const QString BookmarksDatabase::CONNECTION_NAME = QLatin1String("bookmarks_database");
+const QString BookmarksDatabase::BOOKMARK_NAME = QLatin1String("bookmark_name");
+const QString BookmarksDatabase::BOOKMARKS_TABLE = QLatin1String("bookmarks");
+const QString BookmarksDatabase::BOOKMARK_URL = QLatin1String("bookmark_url");
+const QString BookmarksDatabase::DISPLAY_ORDER = QLatin1String("display_order");
+const QString BookmarksDatabase::FAVORITE_ICON = QLatin1String("favorite_icon");
+const QString BookmarksDatabase::FOLDER_ID = QLatin1String("folder_id");
+const QString BookmarksDatabase::ID = QLatin1String("_id");
+const QString BookmarksDatabase::IS_FOLDER = QLatin1String("is_folder");
+const QString BookmarksDatabase::PARENT_FOLDER_ID = QLatin1String("parent_folder_id");
 
 // Construct the class.
 BookmarksDatabase::BookmarksDatabase() {}
@@ -44,7 +44,7 @@ void BookmarksDatabase::addDatabase()
     QSqlDatabase bookmarksDatabase = QSqlDatabase::addDatabase(QStringLiteral("QSQLITE"), CONNECTION_NAME);
 
     // Set the database name.
-    bookmarksDatabase.setDatabaseName(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/bookmarks.db");
+    bookmarksDatabase.setDatabaseName(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1String("/bookmarks.db"));
 
     // Open the database.
     if (bookmarksDatabase.open())  // Opening the database succeeded.
@@ -52,8 +52,11 @@ void BookmarksDatabase::addDatabase()
         // Check to see if the bookmarks table already exists.
         if (bookmarksDatabase.tables().contains(BOOKMARKS_TABLE))  // The bookmarks table already exists.
         {
+            // Create a schema version query.
+            QSqlQuery schemaVersionQuery(bookmarksDatabase);
+
             // Query the database schema version.
-            QSqlQuery schemaVersionQuery = bookmarksDatabase.exec(QStringLiteral("PRAGMA user_version"));
+            schemaVersionQuery.exec(QLatin1String("PRAGMA user_version"));
 
             // Move to the first record.
             schemaVersionQuery.first();
@@ -66,8 +69,11 @@ void BookmarksDatabase::addDatabase()
             {
                 // Run the schema update code.
 
+                // Create an update schema version query.
+                QSqlQuery updateSchemaVersionQuery(bookmarksDatabase);
+
                 // Update the schema version.
-                bookmarksDatabase.exec("PRAGMA user_version = " + QString::number(SCHEMA_VERSION));
+                updateSchemaVersionQuery.exec(QLatin1String("PRAGMA user_version = ") + QString::number(SCHEMA_VERSION));
             }
         }
         else  // The bookmarks table does not exist.
@@ -76,15 +82,15 @@ void BookmarksDatabase::addDatabase()
             QSqlQuery createTableQuery(bookmarksDatabase);
 
             // Populate the create table query.
-            createTableQuery.prepare("CREATE TABLE " + BOOKMARKS_TABLE + "(" +
-                                      ID + " INTEGER PRIMARY KEY, " +
-                                      BOOKMARK_NAME + " TEXT, " +
-                                      BOOKMARK_URL + " TEXT, " +
-                                      PARENT_FOLDER_ID + " INTEGER DEFAULT 0, " +
-                                      DISPLAY_ORDER + " INTEGER DEFAULT 0, " +
-                                      IS_FOLDER + " BOOLEAN DEFAULT FALSE, " +
-                                      FOLDER_ID + " INTEGER DEFAULT 0, " +
-                                      FAVORITE_ICON + " BLOB)");
+            createTableQuery.prepare(QLatin1String("CREATE TABLE ") + BOOKMARKS_TABLE + QLatin1String("(") +
+                                      ID + QLatin1String(" INTEGER PRIMARY KEY, ") +
+                                      BOOKMARK_NAME + QLatin1String(" TEXT, ") +
+                                      BOOKMARK_URL + QLatin1String(" TEXT, ") +
+                                      PARENT_FOLDER_ID + QLatin1String(" INTEGER DEFAULT 0, ") +
+                                      DISPLAY_ORDER + QLatin1String(" INTEGER DEFAULT 0, ") +
+                                      IS_FOLDER + QLatin1String(" BOOLEAN DEFAULT FALSE, ") +
+                                      FOLDER_ID + QLatin1String(" INTEGER DEFAULT 0, ") +
+                                      FAVORITE_ICON + QLatin1String(" BLOB)"));
 
             // Execute the query.
             if (!createTableQuery.exec())
@@ -93,8 +99,11 @@ void BookmarksDatabase::addDatabase()
                 qDebug().noquote().nospace() << "Error creating table:  " << bookmarksDatabase.lastError();
             }
 
+            // Create an update schema version query.
+            QSqlQuery updateSchemaVersionQuery(bookmarksDatabase);
+
             // Set the schema version.
-            bookmarksDatabase.exec("PRAGMA user_version = " + QString::number(SCHEMA_VERSION));
+            updateSchemaVersionQuery.exec(QLatin1String("PRAGMA user_version = ") + QString::number(SCHEMA_VERSION));
         }
     }
     else  // Opening the database failed.
@@ -116,21 +125,20 @@ void BookmarksDatabase::addBookmark(const BookmarkStruct *bookmarkStructPointer)
     QSqlQuery addBookmarkQuery(bookmarksDatabase);
 
     // Prepare the add bookmark query.
-    addBookmarkQuery.prepare("INSERT INTO " + BOOKMARKS_TABLE + " (" +
-                              BOOKMARK_NAME + ", " +
-                              BOOKMARK_URL + ", " +
-                              PARENT_FOLDER_ID + ", " +
-                              DISPLAY_ORDER + ", " +
-                              FAVORITE_ICON + ") " +
-                              "VALUES (:bookmark_name, :bookmark_url, :parent_folder_id, :display_order, :favorite_icon)"
-    );
+    addBookmarkQuery.prepare(QLatin1String("INSERT INTO ") + BOOKMARKS_TABLE + QLatin1String(" (") +
+                              BOOKMARK_NAME + QLatin1String(", ") +
+                              BOOKMARK_URL + QLatin1String(", ") +
+                              PARENT_FOLDER_ID + QLatin1String(", ") +
+                              DISPLAY_ORDER + QLatin1String(", ") +
+                              FAVORITE_ICON + QLatin1String(") ") +
+                              QLatin1String("VALUES (:bookmark_name, :bookmark_url, :parent_folder_id, :display_order, :favorite_icon)"));
 
     // Bind the query values.
-    addBookmarkQuery.bindValue(":bookmark_name", bookmarkStructPointer->name);
-    addBookmarkQuery.bindValue(":bookmark_url", bookmarkStructPointer->url);
-    addBookmarkQuery.bindValue(":parent_folder_id", bookmarkStructPointer->parentFolderId);
-    addBookmarkQuery.bindValue(":display_order", folderItemCount);
-    addBookmarkQuery.bindValue(":favorite_icon", getFavoriteIconBase64String(bookmarkStructPointer->favoriteIcon));
+    addBookmarkQuery.bindValue(QLatin1String(":bookmark_name"), bookmarkStructPointer->name);
+    addBookmarkQuery.bindValue(QLatin1String(":bookmark_url"), bookmarkStructPointer->url);
+    addBookmarkQuery.bindValue(QLatin1String(":parent_folder_id"), bookmarkStructPointer->parentFolderId);
+    addBookmarkQuery.bindValue(QLatin1String(":display_order"), folderItemCount);
+    addBookmarkQuery.bindValue(QLatin1String(":favorite_icon"), getFavoriteIconBase64String(bookmarkStructPointer->favoriteIcon));
 
     // Execute the add bookmark query.
     addBookmarkQuery.exec();
@@ -148,23 +156,22 @@ void BookmarksDatabase::addFolder(const BookmarkStruct *bookmarkStructPointer)
     QSqlQuery addFolderQuery(bookmarksDatabase);
 
     // Prepare the add folder query.
-    addFolderQuery.prepare("INSERT INTO " + BOOKMARKS_TABLE + " (" +
-                              BOOKMARK_NAME + ", " +
-                              PARENT_FOLDER_ID + ", " +
-                              DISPLAY_ORDER + ", " +
-                              IS_FOLDER + ", " +
-                              FOLDER_ID + ", " +
-                              FAVORITE_ICON + ") " +
-                              "VALUES (:bookmark_name, :parent_folder_id, :display_order, :is_folder, :folder_id, :favorite_icon)"
-    );
+    addFolderQuery.prepare(QLatin1String("INSERT INTO ") + BOOKMARKS_TABLE + QLatin1String(" (") +
+                              BOOKMARK_NAME + QLatin1String(", ") +
+                              PARENT_FOLDER_ID + QLatin1String(", ") +
+                              DISPLAY_ORDER + QLatin1String(", ") +
+                              IS_FOLDER + QLatin1String(", ") +
+                              FOLDER_ID + QLatin1String(", ") +
+                              FAVORITE_ICON + QLatin1String(") ") +
+                              QLatin1String("VALUES (:bookmark_name, :parent_folder_id, :display_order, :is_folder, :folder_id, :favorite_icon)"));
 
     // Bind the query values.
-    addFolderQuery.bindValue(":bookmark_name", bookmarkStructPointer->name);
-    addFolderQuery.bindValue(":parent_folder_id", bookmarkStructPointer->parentFolderId);
-    addFolderQuery.bindValue(":display_order", folderItemCount);
-    addFolderQuery.bindValue(":is_folder", 1);
-    addFolderQuery.bindValue(":folder_id", generateFolderId());
-    addFolderQuery.bindValue(":favorite_icon", getFavoriteIconBase64String(bookmarkStructPointer->favoriteIcon));
+    addFolderQuery.bindValue(QLatin1String(":bookmark_name"), bookmarkStructPointer->name);
+    addFolderQuery.bindValue(QLatin1String(":parent_folder_id"), bookmarkStructPointer->parentFolderId);
+    addFolderQuery.bindValue(QLatin1String(":display_order"), folderItemCount);
+    addFolderQuery.bindValue(QLatin1String(":is_folder"), 1);
+    addFolderQuery.bindValue(QLatin1String(":folder_id"), generateFolderId());
+    addFolderQuery.bindValue(QLatin1String(":favorite_icon"), getFavoriteIconBase64String(bookmarkStructPointer->favoriteIcon));
 
     // Execute the add folder query.
     addFolderQuery.exec();
@@ -179,10 +186,10 @@ void BookmarksDatabase::deleteBookmark(const int databaseId)
     QSqlQuery deleteBookmarkQuery(bookmarksDatabase);
 
     // Prepare the delete bookmark query.
-    deleteBookmarkQuery.prepare("DELETE FROM " + BOOKMARKS_TABLE + " WHERE " + ID + " = :id");
+    deleteBookmarkQuery.prepare(QLatin1String("DELETE FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + ID + QLatin1String(" = :id"));
 
     // Bind the query values.
-    deleteBookmarkQuery.bindValue(":id", databaseId);
+    deleteBookmarkQuery.bindValue(QLatin1String(":id"), databaseId);
 
     // Execute the query.
     deleteBookmarkQuery.exec();
@@ -197,10 +204,11 @@ void BookmarksDatabase::deleteBookmarks(const QString url)
     QSqlQuery parentFolderIdsQuery(bookmarksDatabase);
 
     // Prepare the parent folder IDs query.
-    parentFolderIdsQuery.prepare("SELECT " + PARENT_FOLDER_ID + " FROM " + BOOKMARKS_TABLE + " WHERE " + IS_FOLDER + " = 0 AND " + BOOKMARK_URL + " = :url");
+    parentFolderIdsQuery.prepare(QLatin1String("SELECT ") + PARENT_FOLDER_ID + QLatin1String(" FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + IS_FOLDER + QLatin1String(" = 0 AND ") +
+                                 BOOKMARK_URL + QLatin1String(" = :url"));
 
     // Bind the query values.
-    parentFolderIdsQuery.bindValue(":url", url);
+    parentFolderIdsQuery.bindValue(QLatin1String(":url"), url);
 
     // Execute the query.
     parentFolderIdsQuery.exec();
@@ -209,10 +217,10 @@ void BookmarksDatabase::deleteBookmarks(const QString url)
     QSqlQuery deleteBookmarksQuery(bookmarksDatabase);
 
     // Prepare the delete bookmark query.
-    deleteBookmarksQuery.prepare("DELETE FROM " + BOOKMARKS_TABLE + " WHERE " + IS_FOLDER + " = 0 AND " + BOOKMARK_URL + " = :url");
+    deleteBookmarksQuery.prepare(QLatin1String("DELETE FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + IS_FOLDER + QLatin1String(" = 0 AND ") + BOOKMARK_URL + QLatin1String(" = :url"));
 
     // Bind the query values.
-    deleteBookmarksQuery.bindValue(":url", url);
+    deleteBookmarksQuery.bindValue(QLatin1String(":url"), url);
 
     // Execute the query.
     deleteBookmarksQuery.exec();
@@ -250,10 +258,10 @@ double BookmarksDatabase::generateFolderId()
     QSqlQuery existingFolderQuery(bookmarksDatabase);
 
     // Prepare the existing folder query.
-    existingFolderQuery.prepare("SELECT " + ID + " FROM " + BOOKMARKS_TABLE + " WHERE " + FOLDER_ID + " = :possible_folder_id");
+    existingFolderQuery.prepare(QLatin1String("SELECT ") + ID + QLatin1String(" FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + FOLDER_ID + QLatin1String(" = :possible_folder_id"));
 
     // Bind the query values.
-    existingFolderQuery.bindValue(":possible_folder_id", possibleFolderId);
+    existingFolderQuery.bindValue(QLatin1String(":possible_folder_id"), possibleFolderId);
 
     // Execute the query.
     existingFolderQuery.exec();
@@ -277,10 +285,11 @@ QList<QString>* BookmarksDatabase::getAllFolderUrls(const double folderId)
     folderUrlsQuery.setForwardOnly(true);
 
     // Prepare the folder URLs query.
-    folderUrlsQuery.prepare("SELECT " + BOOKMARK_URL + ", " + IS_FOLDER + ", " + FOLDER_ID + " FROM " + BOOKMARKS_TABLE + " WHERE " + PARENT_FOLDER_ID + " = :parent_folder_id");
+    folderUrlsQuery.prepare(QLatin1String("SELECT ") + BOOKMARK_URL + QLatin1String(", ") + IS_FOLDER + QLatin1String(", ") + FOLDER_ID + QLatin1String(" FROM ") + BOOKMARKS_TABLE +
+                            QLatin1String(" WHERE ") + PARENT_FOLDER_ID + QLatin1String(" = :parent_folder_id"));
 
     // Bind the query values.
-    folderUrlsQuery.bindValue(":parent_folder_id", folderId);
+    folderUrlsQuery.bindValue(QLatin1String(":parent_folder_id"), folderId);
 
     // Execute the query.
     folderUrlsQuery.exec();
@@ -320,10 +329,10 @@ BookmarkStruct* BookmarksDatabase::getBookmark(const int databaseId)
     bookmarkQuery.setForwardOnly(true);
 
     // Prepare the bookmark query.
-    bookmarkQuery.prepare("SELECT * FROM " + BOOKMARKS_TABLE + " WHERE " + ID + " = :id");
+    bookmarkQuery.prepare(QLatin1String("SELECT * FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + ID + QLatin1String(" = :id"));
 
     // Bind the query values.
-    bookmarkQuery.bindValue(":id", databaseId);
+    bookmarkQuery.bindValue(QLatin1String(":id"), databaseId);
 
     // Execute the query.
     bookmarkQuery.exec();
@@ -369,7 +378,7 @@ std::list<BookmarkStruct>* BookmarksDatabase::getBookmarks()
     bookmarksQuery.setForwardOnly(true);
 
     // Prepare the bookmarks query.
-    bookmarksQuery.prepare("SELECT * FROM " + BOOKMARKS_TABLE + " ORDER BY " + DISPLAY_ORDER + " ASC");
+    bookmarksQuery.prepare(QLatin1String("SELECT * FROM ") + BOOKMARKS_TABLE + QLatin1String(" ORDER BY ") + DISPLAY_ORDER + QLatin1String(" ASC"));
 
     // Execute the query.
     bookmarksQuery.exec();
@@ -438,10 +447,11 @@ QList<BookmarkStruct>* BookmarksDatabase::getBookmarksInFolderExcept(const doubl
     }
 
     // Prepare the bookmarks query.
-    bookmarksQuery.prepare("SELECT * FROM " + BOOKMARKS_TABLE + " WHERE " + PARENT_FOLDER_ID + " = :parent_folder_id AND " + ID + " NOT IN (" + idsNotToGetString + ") ORDER BY " + DISPLAY_ORDER + " ASC");
+    bookmarksQuery.prepare(QLatin1String("SELECT * FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + PARENT_FOLDER_ID + QLatin1String(" = :parent_folder_id AND ") + ID +
+                           QLatin1String(" NOT IN (") + idsNotToGetString + QLatin1String(") ORDER BY ") + DISPLAY_ORDER + QLatin1String(" ASC"));
 
     // Bind the query values.
-    bookmarksQuery.bindValue(":parent_folder_id", folderId);
+    bookmarksQuery.bindValue(QLatin1String(":parent_folder_id"), folderId);
 
     // Execute the query.
     bookmarksQuery.exec();
@@ -503,7 +513,7 @@ QString BookmarksDatabase::getFavoriteIconBase64String(const QIcon &favoriteIcon
     favoriteIconBuffer.close();
 
     // Convert the favorite icon byte array to a base 64 string.
-    QString favoriteIconBase64String = favoriteIconByteArray.toBase64();
+    QString favoriteIconBase64String = QLatin1String(favoriteIconByteArray.toBase64());
 
     // Return the favorite icon base 64 string.
     return favoriteIconBase64String;
@@ -521,10 +531,11 @@ QList<BookmarkStruct>* BookmarksDatabase::getFolderContents(const double folderI
     folderContentsQuery.setForwardOnly(true);
 
     // Prepare the folder contents query.
-    folderContentsQuery.prepare("SELECT * FROM " + BOOKMARKS_TABLE + " WHERE " + PARENT_FOLDER_ID + " = :parent_folder_id ORDER BY " + DISPLAY_ORDER + " ASC");
+    folderContentsQuery.prepare(QLatin1String("SELECT * FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + PARENT_FOLDER_ID + QLatin1String(" = :parent_folder_id ORDER BY ") + DISPLAY_ORDER +
+                                QLatin1String(" ASC"));
 
     // Bind the query values.
-    folderContentsQuery.bindValue(":parent_folder_id", folderId);
+    folderContentsQuery.bindValue(QLatin1String(":parent_folder_id"), folderId);
 
     // Execute the query.
     folderContentsQuery.exec();
@@ -577,10 +588,10 @@ QList<int>* BookmarksDatabase::getFolderContentsDatabaseIds(const double folderI
     folderContentsQuery.setForwardOnly(true);
 
     // Prepare the folder contents query.
-    folderContentsQuery.prepare("SELECT " + ID + " FROM " + BOOKMARKS_TABLE + " WHERE " + PARENT_FOLDER_ID + " = :parent_folder_id");
+    folderContentsQuery.prepare(QLatin1String("SELECT ") + ID + QLatin1String(" FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + PARENT_FOLDER_ID + QLatin1String(" = :parent_folder_id"));
 
     // Bind the query values.
-    folderContentsQuery.bindValue(":parent_folder_id", folderId);
+    folderContentsQuery.bindValue(QLatin1String(":parent_folder_id"), folderId);
 
     // Execute the query.
     folderContentsQuery.exec();
@@ -611,10 +622,11 @@ QList<int> *BookmarksDatabase::getFolderContentsDatabaseIdsRecursively(const dou
     folderContentsQuery.setForwardOnly(true);
 
     // Prepare the folder contents query.
-    folderContentsQuery.prepare("SELECT " + ID + ", " + IS_FOLDER + ", " + FOLDER_ID + " FROM " + BOOKMARKS_TABLE + " WHERE " + PARENT_FOLDER_ID + " = :parent_folder_id");
+    folderContentsQuery.prepare(QLatin1String("SELECT ") + ID + QLatin1String(", ") + IS_FOLDER + QLatin1String(", ") + FOLDER_ID + QLatin1String(" FROM ") + BOOKMARKS_TABLE +
+                                QLatin1String(" WHERE ") + PARENT_FOLDER_ID + QLatin1String(" = :parent_folder_id"));
 
     // Bind the query values.
-    folderContentsQuery.bindValue(":parent_folder_id", folderId);
+    folderContentsQuery.bindValue(QLatin1String(":parent_folder_id"), folderId);
 
     // Execute the query.
     folderContentsQuery.exec();
@@ -649,10 +661,10 @@ int BookmarksDatabase::getFolderDatabaseId(const double folderId)
     folderDatabaseIdQuery.setForwardOnly(true);
 
     // Prepare the folder database ID query.
-    folderDatabaseIdQuery.prepare("SELECT " + ID + " FROM " + BOOKMARKS_TABLE + " WHERE " + FOLDER_ID + " = :folder_id");
+    folderDatabaseIdQuery.prepare(QLatin1String("SELECT ") + ID + QLatin1String(" FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + FOLDER_ID + QLatin1String(" = :folder_id"));
 
     // Bind the query values.
-    folderDatabaseIdQuery.bindValue(":folder_id", folderId);
+    folderDatabaseIdQuery.bindValue(QLatin1String(":folder_id"), folderId);
 
     // Execute the query.
     folderDatabaseIdQuery.exec();
@@ -676,10 +688,10 @@ double BookmarksDatabase::getFolderId(const int databaseId)
     folderIdQuery.setForwardOnly(true);
 
     // Prepare the folder ID query.
-    folderIdQuery.prepare("SELECT " + FOLDER_ID + " FROM " + BOOKMARKS_TABLE + " WHERE " + ID + " = :database_id");
+    folderIdQuery.prepare(QLatin1String("SELECT ") + FOLDER_ID + QLatin1String(" FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + ID + QLatin1String(" = :database_id"));
 
     // Bind the query values.
-    folderIdQuery.bindValue(":database_id", databaseId);
+    folderIdQuery.bindValue(QLatin1String(":database_id"), databaseId);
 
     // Execute the query.
     folderIdQuery.exec();
@@ -703,10 +715,10 @@ int BookmarksDatabase::getFolderItemCount(const double folderId)
     folderContentsQuery.setForwardOnly(true);
 
     // Prepare the folder contents query.
-    folderContentsQuery.prepare("SELECT " + ID + " FROM " + BOOKMARKS_TABLE + " WHERE " + PARENT_FOLDER_ID + " = :parent_folder_id");
+    folderContentsQuery.prepare(QLatin1String("SELECT ") + ID + QLatin1String(" FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + PARENT_FOLDER_ID + QLatin1String(" = :parent_folder_id"));
 
     // Bind the query values.
-    folderContentsQuery.bindValue(":parent_folder_id", folderId);
+    folderContentsQuery.bindValue(QLatin1String(":parent_folder_id"), folderId);
 
     // Execute the query.
     folderContentsQuery.exec();
@@ -740,10 +752,10 @@ double BookmarksDatabase::getParentFolderId(const int databaseId)
     parentFolderIdQuery.setForwardOnly(true);
 
     // Prepare the parent folder ID query.
-    parentFolderIdQuery.prepare("SELECT " + PARENT_FOLDER_ID + " FROM " + BOOKMARKS_TABLE + " WHERE " + ID + " = :database_id");
+    parentFolderIdQuery.prepare(QLatin1String("SELECT ") + PARENT_FOLDER_ID + QLatin1String(" FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + ID + QLatin1String(" = :database_id"));
 
     // Bind the query values.
-    parentFolderIdQuery.bindValue(":database_id", databaseId);
+    parentFolderIdQuery.bindValue(QLatin1String(":database_id"), databaseId);
 
     // Execute the query.
     parentFolderIdQuery.exec();
@@ -767,10 +779,11 @@ QList<BookmarkStruct>* BookmarksDatabase::getSubfolders(const double folderId)
     subfoldersQuery.setForwardOnly(true);
 
     // Prepare the subfolders query.
-    subfoldersQuery.prepare("SELECT * FROM " + BOOKMARKS_TABLE + " WHERE " + IS_FOLDER + " = 1 AND " + PARENT_FOLDER_ID + " = :parent_folder_id ORDER BY " + DISPLAY_ORDER + " ASC");
+    subfoldersQuery.prepare(QLatin1String("SELECT * FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + IS_FOLDER + QLatin1String(" = 1 AND ") + PARENT_FOLDER_ID +
+                            QLatin1String(" = :parent_folder_id ORDER BY ") + DISPLAY_ORDER + QLatin1String(" ASC"));
 
     // Bind the query values.
-    subfoldersQuery.bindValue(":parent_folder_id", folderId);
+    subfoldersQuery.bindValue(QLatin1String(":parent_folder_id"), folderId);
 
     // Execute the query.
     subfoldersQuery.exec();
@@ -822,10 +835,11 @@ bool BookmarksDatabase::isBookmarked(const QString url)
     isBookmarkedQuery.setForwardOnly(true);
 
     // Prepare the is bookmarked query.
-    isBookmarkedQuery.prepare("SELECT " + ID + " FROM " + BOOKMARKS_TABLE + " WHERE " + IS_FOLDER + " = 0 AND " + BOOKMARK_URL + " = :url");
+    isBookmarkedQuery.prepare(QLatin1String("SELECT ") + ID + QLatin1String(" FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + IS_FOLDER + QLatin1String(" = 0 AND ") + BOOKMARK_URL +
+                              QLatin1String(" = :url"));
 
     // Bind the query values.
-    isBookmarkedQuery.bindValue(":url", url);
+    isBookmarkedQuery.bindValue(QLatin1String(":url"), url);
 
     // Execute the query.
     isBookmarkedQuery.exec();
@@ -849,10 +863,10 @@ bool BookmarksDatabase::isFolder(const int databaseId)
     isFolderQuery.setForwardOnly(true);
 
     // Prepare the is folder query.
-    isFolderQuery.prepare("SELECT " + IS_FOLDER + " FROM " + BOOKMARKS_TABLE + " WHERE " + ID + " = :id");
+    isFolderQuery.prepare(QLatin1String("SELECT ") + IS_FOLDER + QLatin1String(" FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + ID + QLatin1String(" = :id"));
 
     // Bind the query values.
-    isFolderQuery.bindValue(":id", databaseId);
+    isFolderQuery.bindValue(QLatin1String(":id"), databaseId);
 
     // Execute the query.
     isFolderQuery.exec();
@@ -873,21 +887,21 @@ void BookmarksDatabase::updateBookmark(const BookmarkStruct *bookmarkStructPoint
     QSqlQuery updateBookmarkQuery(bookmarksDatabase);
 
     // Prepare the update bookmark query.
-    updateBookmarkQuery.prepare("UPDATE " + BOOKMARKS_TABLE + " SET " +
-                                BOOKMARK_NAME + " = :bookmark_name, " +
-                                BOOKMARK_URL + " = :bookmark_url, " +
-                                PARENT_FOLDER_ID + " = :parent_folder_id, " +
-                                DISPLAY_ORDER + " = :display_order, " +
-                                FAVORITE_ICON + "= :favorite_icon " +
-                                "WHERE " + ID + " = :id");
+    updateBookmarkQuery.prepare(QLatin1String("UPDATE ") + BOOKMARKS_TABLE + QLatin1String(" SET ") +
+                                BOOKMARK_NAME + QLatin1String(" = :bookmark_name, ") +
+                                BOOKMARK_URL + QLatin1String(" = :bookmark_url, ") +
+                                PARENT_FOLDER_ID + QLatin1String(" = :parent_folder_id, ") +
+                                DISPLAY_ORDER + QLatin1String(" = :display_order, ") +
+                                FAVORITE_ICON + QLatin1String("= :favorite_icon ") +
+                                QLatin1String("WHERE ") + ID + QLatin1String(" = :id"));
 
     // Bind the query values.
-    updateBookmarkQuery.bindValue(":bookmark_name", bookmarkStructPointer->name);
-    updateBookmarkQuery.bindValue(":bookmark_url", bookmarkStructPointer->url);
-    updateBookmarkQuery.bindValue(":parent_folder_id", bookmarkStructPointer->parentFolderId);
-    updateBookmarkQuery.bindValue(":display_order", bookmarkStructPointer->displayOrder);
-    updateBookmarkQuery.bindValue(":favorite_icon", getFavoriteIconBase64String(bookmarkStructPointer->favoriteIcon));
-    updateBookmarkQuery.bindValue(":id", bookmarkStructPointer->databaseId);
+    updateBookmarkQuery.bindValue(QLatin1String(":bookmark_name"), bookmarkStructPointer->name);
+    updateBookmarkQuery.bindValue(QLatin1String(":bookmark_url"), bookmarkStructPointer->url);
+    updateBookmarkQuery.bindValue(QLatin1String(":parent_folder_id"), bookmarkStructPointer->parentFolderId);
+    updateBookmarkQuery.bindValue(QLatin1String(":display_order"), bookmarkStructPointer->displayOrder);
+    updateBookmarkQuery.bindValue(QLatin1String(":favorite_icon"), getFavoriteIconBase64String(bookmarkStructPointer->favoriteIcon));
+    updateBookmarkQuery.bindValue(QLatin1String(":id"), bookmarkStructPointer->databaseId);
 
     // Execute the query.
     updateBookmarkQuery.exec();
@@ -902,13 +916,13 @@ void BookmarksDatabase::updateBookmarkName(const int databaseId, const QString &
     QSqlQuery updateBookmarkNameQuery(bookmarksDatabase);
 
     // Prepare the update bookmark name query.
-    updateBookmarkNameQuery.prepare("UPDATE " + BOOKMARKS_TABLE +
-                                    " SET " + BOOKMARK_NAME + " = :bookmark_name " +
-                                    "WHERE " + ID + " = :id");
+    updateBookmarkNameQuery.prepare(QLatin1String("UPDATE ") + BOOKMARKS_TABLE +
+                                    QLatin1String(" SET ") + BOOKMARK_NAME + QLatin1String(" = :bookmark_name ") +
+                                    QLatin1String("WHERE ") + ID + QLatin1String(" = :id"));
 
     // Bind the query values.
-    updateBookmarkNameQuery.bindValue(":bookmark_name", bookmarkName);
-    updateBookmarkNameQuery.bindValue(":id", databaseId);
+    updateBookmarkNameQuery.bindValue(QLatin1String(":bookmark_name"), bookmarkName);
+    updateBookmarkNameQuery.bindValue(QLatin1String(":id"), databaseId);
 
     // Execute the query.
     updateBookmarkNameQuery.exec();
@@ -923,13 +937,13 @@ void BookmarksDatabase::updateBookmarkUrl(const int databaseId, const QString &b
     QSqlQuery updateBookmarkUrlQuery(bookmarksDatabase);
 
     // Prepare the update bookmark URL query.
-    updateBookmarkUrlQuery.prepare("UPDATE " + BOOKMARKS_TABLE +
-                                   " SET " + BOOKMARK_URL + " = :bookmark_url " +
-                                   "WHERE " + ID + " = :id");
+    updateBookmarkUrlQuery.prepare(QLatin1String("UPDATE ") + BOOKMARKS_TABLE +
+                                   QLatin1String(" SET ") + BOOKMARK_URL + QLatin1String(" = :bookmark_url ") +
+                                   QLatin1String("WHERE ") + ID + QLatin1String(" = :id"));
 
     // Bind the query values.
-    updateBookmarkUrlQuery.bindValue(":bookmark_url", bookmarkUrl);
-    updateBookmarkUrlQuery.bindValue(":id", databaseId);
+    updateBookmarkUrlQuery.bindValue(QLatin1String(":bookmark_url"), bookmarkUrl);
+    updateBookmarkUrlQuery.bindValue(QLatin1String(":id"), databaseId);
 
     // Execute the query.
     updateBookmarkUrlQuery.exec();
@@ -944,13 +958,13 @@ void BookmarksDatabase::updateDisplayOrder(const int databaseId, const int displ
     QSqlQuery updateBookmarkDisplayOrderQuery(bookmarksDatabase);
 
     // Prepare the update bookmark display order query.
-    updateBookmarkDisplayOrderQuery.prepare("UPDATE " + BOOKMARKS_TABLE +
-                                            " SET " + DISPLAY_ORDER + " = :display_order " +
-                                            "WHERE " + ID + " = :id");
+    updateBookmarkDisplayOrderQuery.prepare(QLatin1String("UPDATE ") + BOOKMARKS_TABLE +
+                                            QLatin1String(" SET ") + DISPLAY_ORDER + QLatin1String(" = :display_order ") +
+                                            QLatin1String("WHERE ") + ID + QLatin1String(" = :id"));
 
     // Bind the query values.
-    updateBookmarkDisplayOrderQuery.bindValue(":display_order", displayOrder);
-    updateBookmarkDisplayOrderQuery.bindValue(":id", databaseId);
+    updateBookmarkDisplayOrderQuery.bindValue(QLatin1String(":display_order"), displayOrder);
+    updateBookmarkDisplayOrderQuery.bindValue(QLatin1String(":id"), databaseId);
 
     // Execute the query.
     updateBookmarkDisplayOrderQuery.exec();
@@ -968,10 +982,11 @@ void BookmarksDatabase::updateFolderContentsDisplayOrder(const double folderId)
     folderContentsQuery.setForwardOnly(true);
 
     // Prepare the folder contents query.
-    folderContentsQuery.prepare("SELECT " + ID + ", " + DISPLAY_ORDER + " FROM " + BOOKMARKS_TABLE + " WHERE " + PARENT_FOLDER_ID + " = :parent_folder_id ORDER BY " + DISPLAY_ORDER + " ASC");
+    folderContentsQuery.prepare(QLatin1String("SELECT ") + ID + QLatin1String(", ") + DISPLAY_ORDER + QLatin1String(" FROM ") + BOOKMARKS_TABLE + QLatin1String(" WHERE ") + PARENT_FOLDER_ID +
+                                QLatin1String(" = :parent_folder_id ORDER BY ") + DISPLAY_ORDER + QLatin1String(" ASC"));
 
     // Bind the query values.
-    folderContentsQuery.bindValue(":parent_folder_id", folderId);
+    folderContentsQuery.bindValue(QLatin1String(":parent_folder_id"), folderId);
 
     // Execute the query.
     folderContentsQuery.exec();
@@ -1000,15 +1015,15 @@ void BookmarksDatabase::updateParentFolderAndDisplayOrder(const int databaseId,
     QSqlQuery updateBookmarkDisplayOrderQuery(bookmarksDatabase);
 
     // Prepare the update bookmark display order query.
-    updateBookmarkDisplayOrderQuery.prepare("UPDATE " + BOOKMARKS_TABLE +
-                                            " SET " + PARENT_FOLDER_ID + " = :parent_folder_id " +
-                                            ", " + DISPLAY_ORDER + " = :display_order " +
-                                            "WHERE " + ID + " = :id");
+    updateBookmarkDisplayOrderQuery.prepare(QLatin1String("UPDATE ") + BOOKMARKS_TABLE +
+                                            QLatin1String(" SET ") + PARENT_FOLDER_ID + QLatin1String(" = :parent_folder_id ,") +
+                                            DISPLAY_ORDER + QLatin1String(" = :display_order ") +
+                                            QLatin1String("WHERE ") + ID + QLatin1String(" = :id"));
 
     // Bind the query values.
-    updateBookmarkDisplayOrderQuery.bindValue(":parent_folder_id", parentFolderId);
-    updateBookmarkDisplayOrderQuery.bindValue(":display_order", displayOrder);
-    updateBookmarkDisplayOrderQuery.bindValue(":id", databaseId);
+    updateBookmarkDisplayOrderQuery.bindValue(QLatin1String(":parent_folder_id"), parentFolderId);
+    updateBookmarkDisplayOrderQuery.bindValue(QLatin1String(":display_order"), displayOrder);
+    updateBookmarkDisplayOrderQuery.bindValue(QLatin1String(":id"), databaseId);
 
     // Execute the query.
     updateBookmarkDisplayOrderQuery.exec();
