@@ -1,20 +1,20 @@
-/*
- * Copyright 2022-2024 Soren Stoutner <soren@stoutner.com>.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-FileCopyrightText: 2022-2024 Soren Stoutner <soren@stoutner.com>
  *
  * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc/>.
  *
- * Privacy Browser PC is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
  *
- * Privacy Browser PC is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 // Application headers.
@@ -26,21 +26,21 @@
 const int DomainsDatabase::SCHEMA_VERSION = 7;
 
 // Define the public static constants.
-const QString DomainsDatabase::CONNECTION_NAME = "domains_database";
-const QString DomainsDatabase::CUSTOM_ZOOM_FACTOR = "custom_zoom_factor";
-const QString DomainsDatabase::DOM_STORAGE = "dom_storage";
-const QString DomainsDatabase::DOMAIN_NAME = "domain_name";
-const QString DomainsDatabase::DOMAINS_TABLE = "domains";
-const QString DomainsDatabase::EASYLIST = "easylist";
-const QString DomainsDatabase::EASYPRIVACY = "easyprivacy";
-const QString DomainsDatabase::FANBOYS_ANNOYANCE_LIST = "fanboys_annoyance_list";
-const QString DomainsDatabase::ID = "_id";
-const QString DomainsDatabase::JAVASCRIPT = "javascript";
-const QString DomainsDatabase::LOCAL_STORAGE = "local_storage";
-const QString DomainsDatabase::ULTRALIST = "ultralist";
-const QString DomainsDatabase::ULTRAPRIVACY = "ultraprivacy";
-const QString DomainsDatabase::USER_AGENT = "user_agent";
-const QString DomainsDatabase::ZOOM_FACTOR = "zoom_factor";
+const QString DomainsDatabase::CONNECTION_NAME = QLatin1String("domains_database");
+const QString DomainsDatabase::CUSTOM_ZOOM_FACTOR = QLatin1String("custom_zoom_factor");
+const QString DomainsDatabase::DOM_STORAGE = QLatin1String("dom_storage");
+const QString DomainsDatabase::DOMAIN_NAME = QLatin1String("domain_name");
+const QString DomainsDatabase::DOMAINS_TABLE = QLatin1String("domains");
+const QString DomainsDatabase::EASYLIST = QLatin1String("easylist");
+const QString DomainsDatabase::EASYPRIVACY = QLatin1String("easyprivacy");
+const QString DomainsDatabase::FANBOYS_ANNOYANCE_LIST = QLatin1String("fanboys_annoyance_list");
+const QString DomainsDatabase::ID = QLatin1String("_id");
+const QString DomainsDatabase::JAVASCRIPT = QLatin1String("javascript");
+const QString DomainsDatabase::LOCAL_STORAGE = QLatin1String("local_storage");
+const QString DomainsDatabase::ULTRALIST = QLatin1String("ultralist");
+const QString DomainsDatabase::ULTRAPRIVACY = QLatin1String("ultraprivacy");
+const QString DomainsDatabase::USER_AGENT = QLatin1String("user_agent");
+const QString DomainsDatabase::ZOOM_FACTOR = QLatin1String("zoom_factor");
 
 // Construct the class.
 DomainsDatabase::DomainsDatabase() {}
@@ -51,7 +51,7 @@ void DomainsDatabase::addDatabase()
     QSqlDatabase domainsDatabase = QSqlDatabase::addDatabase(QStringLiteral("QSQLITE"), CONNECTION_NAME);
 
     // Set the database name.
-    domainsDatabase.setDatabaseName(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/domains.db");
+    domainsDatabase.setDatabaseName(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1String("/domains.db"));
 
     // Open the database.
     if (domainsDatabase.open())  // Opening the database succeeded.
@@ -59,8 +59,11 @@ void DomainsDatabase::addDatabase()
         // Check to see if the domains table already exists.
         if (domainsDatabase.tables().contains(DOMAINS_TABLE))  // The domains table already exists.
         {
+            // Create a schema version query.
+            QSqlQuery schemaVersionQuery(domainsDatabase);
+
             // Query the database schema version.
-            QSqlQuery schemaVersionQuery = domainsDatabase.exec(QStringLiteral("PRAGMA user_version"));
+            schemaVersionQuery.exec(QLatin1String("PRAGMA user_version"));
 
             // Move to the first record.
             schemaVersionQuery.first();
@@ -77,8 +80,11 @@ void DomainsDatabase::addDatabase()
                     // Upgrade from schema version 0 to schema version 1.
                     case 0:
                     {
+                        // Create an add JavaScript query.
+                        QSqlQuery addJavaScriptQuery(domainsDatabase);
+
                         // Add the JavaScript column.
-                        domainsDatabase.exec("ALTER TABLE " + DOMAINS_TABLE + " ADD COLUMN " + JAVASCRIPT + " INTEGER DEFAULT 0");
+                        addJavaScriptQuery.exec(QLatin1String("ALTER TABLE ") + DOMAINS_TABLE + QLatin1String(" ADD COLUMN ") + JAVASCRIPT + QLatin1String(" INTEGER DEFAULT 0"));
 
                         // Fall through to the next case.
                         [[fallthrough]];
@@ -87,8 +93,12 @@ void DomainsDatabase::addDatabase()
                     // Upgrade from schema version 1 to schema version 2.
                     case 1:
                     {
+                        // Create an add user agent query.
+                        QSqlQuery addUserAgentQuery(domainsDatabase);
+
                         // Add the User Agent column.
-                        domainsDatabase.exec("ALTER TABLE " + DOMAINS_TABLE + " ADD COLUMN " + USER_AGENT + " TEXT DEFAULT '" + UserAgentHelper::SYSTEM_DEFAULT_DATABASE + "'");
+                        addUserAgentQuery.exec(QLatin1String("ALTER TABLE ") + DOMAINS_TABLE + QLatin1String(" ADD COLUMN ") + USER_AGENT + QLatin1String(" TEXT DEFAULT '") +
+                                               UserAgentHelper::SYSTEM_DEFAULT_DATABASE + QLatin1String("'"));
 
                         // Fall through to the next case.
                         [[fallthrough]];
@@ -97,9 +107,12 @@ void DomainsDatabase::addDatabase()
                     // Upgrade from schema version 2 to schema version 3.
                     case 2:
                     {
+                        // Create an add zoom factor query.
+                        QSqlQuery addZoomFactorQuery(domainsDatabase);
+
                         // Add the Zoom Factor columns.
-                        domainsDatabase.exec("ALTER TABLE " + DOMAINS_TABLE + " ADD COLUMN " + ZOOM_FACTOR + " INTEGER DEFAULT 0");
-                        domainsDatabase.exec("ALTER TABLE " + DOMAINS_TABLE + " ADD COLUMN " + CUSTOM_ZOOM_FACTOR + " REAL DEFAULT 1.0");
+                        addZoomFactorQuery.exec(QLatin1String("ALTER TABLE ") + DOMAINS_TABLE + QLatin1String(" ADD COLUMN ") + ZOOM_FACTOR + QLatin1String(" INTEGER DEFAULT 0"));
+                        addZoomFactorQuery.exec(QLatin1String("ALTER TABLE ") + DOMAINS_TABLE + QLatin1String(" ADD COLUMN ") + CUSTOM_ZOOM_FACTOR + QLatin1String(" REAL DEFAULT 1.0"));
 
                         // Fall through to the next case.
                         [[fallthrough]];
@@ -108,8 +121,11 @@ void DomainsDatabase::addDatabase()
                     // Upgrade from schema version 3 to schema version 4.
                     case 3:
                     {
+                        // Create an add DOM storage query.
+                        QSqlQuery addDomStorageQuery(domainsDatabase);
+
                         // Add the DOM Storage column.
-                        domainsDatabase.exec("ALTER TABLE " + DOMAINS_TABLE + " ADD COLUMN " + DOM_STORAGE + " INTEGER DEFAULT 0");
+                        addDomStorageQuery.exec(QLatin1String("ALTER TABLE ") + DOMAINS_TABLE + QLatin1String(" ADD COLUMN ") + DOM_STORAGE + QLatin1String(" INTEGER DEFAULT 0"));
 
                         // Fall through to the next case.
                         [[fallthrough]];
@@ -118,8 +134,11 @@ void DomainsDatabase::addDatabase()
                     // Upgrade from schema version 4 to schema version 5, first used in Privacy Browser PC 0.1.
                     case 4:
                     {
+                        // Create an add local storage query.
+                        QSqlQuery addLocalStorageQuery(domainsDatabase);
+
                         // Add the Local Storage column.
-                        domainsDatabase.exec("ALTER TABLE " + DOMAINS_TABLE + " ADD COLUMN " + LOCAL_STORAGE + " INTEGER DEFAULT 0");
+                        addLocalStorageQuery.exec(QLatin1String("ALTER TABLE ") + DOMAINS_TABLE + QLatin1String(" ADD COLUMN ") + LOCAL_STORAGE + QLatin1String(" INTEGER DEFAULT 0"));
 
                         // Fall through to the next case.
                         [[fallthrough]];
@@ -135,7 +154,8 @@ void DomainsDatabase::addDatabase()
                         spinnerQuery.setForwardOnly(true);
 
                         // Prepare the query.
-                        spinnerQuery.prepare("SELECT " + ID + "," + JAVASCRIPT + "," + LOCAL_STORAGE + "," + DOM_STORAGE + " FROM " + DOMAINS_TABLE);
+                        spinnerQuery.prepare(QLatin1String("SELECT ") + ID + QLatin1String(",") + JAVASCRIPT + QLatin1String(",") + LOCAL_STORAGE + QLatin1String(",") + DOM_STORAGE +
+                                             QLatin1String(" FROM ") + DOMAINS_TABLE);
 
                         // Execute the query.
                         spinnerQuery.exec();
@@ -218,17 +238,17 @@ void DomainsDatabase::addDatabase()
                             QSqlQuery updateSpinnerQuery(domainsDatabase);
 
                             // Prepare the update spinner query.
-                            updateSpinnerQuery.prepare("UPDATE " + DOMAINS_TABLE + " SET " +
-                                                 JAVASCRIPT + " = :javascript , " +
-                                                 LOCAL_STORAGE + " = :local_storage , " +
-                                                 DOM_STORAGE + " = :dom_storage " +
-                                                 " WHERE " + ID + " = :id");
+                            updateSpinnerQuery.prepare(QLatin1String("UPDATE ") + DOMAINS_TABLE + QLatin1String(" SET ") +
+                                                 JAVASCRIPT + QLatin1String(" = :javascript , ") +
+                                                 LOCAL_STORAGE + QLatin1String(" = :local_storage , ") +
+                                                 DOM_STORAGE + QLatin1String(" = :dom_storage ") +
+                                                 QLatin1String(" WHERE ") + ID + QLatin1String(" = :id"));
 
                             // Bind the values.
-                            updateSpinnerQuery.bindValue(":javascript", newJavaScriptValue);
-                            updateSpinnerQuery.bindValue(":local_storage", newLocalStorageValue);
-                            updateSpinnerQuery.bindValue(":dom_storage", newDomStorageValue);
-                            updateSpinnerQuery.bindValue(":id", spinnerQuery.value(ID));
+                            updateSpinnerQuery.bindValue(QLatin1String(":javascript"), newJavaScriptValue);
+                            updateSpinnerQuery.bindValue(QLatin1String(":local_storage"), newLocalStorageValue);
+                            updateSpinnerQuery.bindValue(QLatin1String(":dom_storage"), newDomStorageValue);
+                            updateSpinnerQuery.bindValue(QLatin1String(":id"), spinnerQuery.value(ID));
 
                             // Execute the query.
                             updateSpinnerQuery.exec();
@@ -241,20 +261,26 @@ void DomainsDatabase::addDatabase()
                     // Upgrade from schema version 6 to schema version 7, first used in Privacy Browser PC 0.6.
                     case 6:
                     {
+                        // Create an add filter lists query.
+                        QSqlQuery addFilterListsQuery(domainsDatabase);
+
                         // Add the filter list columns.
-                        domainsDatabase.exec("ALTER TABLE " + DOMAINS_TABLE + " ADD COLUMN " + ULTRAPRIVACY + " INTEGER DEFAULT 0");
-                        domainsDatabase.exec("ALTER TABLE " + DOMAINS_TABLE + " ADD COLUMN " + ULTRALIST + " INTEGER DEFAULT 0");
-                        domainsDatabase.exec("ALTER TABLE " + DOMAINS_TABLE + " ADD COLUMN " + EASYPRIVACY + " INTEGER DEFAULT 0");
-                        domainsDatabase.exec("ALTER TABLE " + DOMAINS_TABLE + " ADD COLUMN " + EASYLIST + " INTEGER DEFAULT 0");
-                        domainsDatabase.exec("ALTER TABLE " + DOMAINS_TABLE + " ADD COLUMN " + FANBOYS_ANNOYANCE_LIST + " INTEGER DEFAULT 0");
+                        addFilterListsQuery.exec(QLatin1String("ALTER TABLE ") + DOMAINS_TABLE + QLatin1String(" ADD COLUMN ") + ULTRAPRIVACY + QLatin1String(" INTEGER DEFAULT 0"));
+                        addFilterListsQuery.exec(QLatin1String("ALTER TABLE ") + DOMAINS_TABLE + QLatin1String(" ADD COLUMN ") + ULTRALIST + QLatin1String(" INTEGER DEFAULT 0"));
+                        addFilterListsQuery.exec(QLatin1String("ALTER TABLE ") + DOMAINS_TABLE + QLatin1String(" ADD COLUMN ") + EASYPRIVACY + QLatin1String(" INTEGER DEFAULT 0"));
+                        addFilterListsQuery.exec(QLatin1String("ALTER TABLE ") + DOMAINS_TABLE + QLatin1String(" ADD COLUMN ") + EASYLIST + QLatin1String(" INTEGER DEFAULT 0"));
+                        addFilterListsQuery.exec(QLatin1String("ALTER TABLE ") + DOMAINS_TABLE + QLatin1String(" ADD COLUMN ") + FANBOYS_ANNOYANCE_LIST + QLatin1String(" INTEGER DEFAULT 0"));
 
                         // Fall through to the next case.
                         // [[fallthrough]];
                     }
                 }
 
+                // Create an update scheme version query.
+                QSqlQuery updateSchemaVersionQuery(domainsDatabase);
+
                 // Update the schema version.
-                domainsDatabase.exec("PRAGMA user_version = " + QString::number(SCHEMA_VERSION));
+                updateSchemaVersionQuery.exec(QLatin1String("PRAGMA user_version = ") + QString::number(SCHEMA_VERSION));
             }
         }
         else  // The domains table does not exist.
@@ -263,20 +289,20 @@ void DomainsDatabase::addDatabase()
             QSqlQuery createTableQuery(domainsDatabase);
 
             // Prepare the create table query.
-            createTableQuery.prepare("CREATE TABLE " + DOMAINS_TABLE + "(" +
-                                     ID + " INTEGER PRIMARY KEY, " +
-                                     DOMAIN_NAME + " TEXT, " +
-                                     JAVASCRIPT + " INTEGER DEFAULT 0, " +
-                                     LOCAL_STORAGE + " INTEGER DEFAULT 0, " +
-                                     DOM_STORAGE + " INTEGER DEFAULT 0, " +
-                                     USER_AGENT + " TEXT DEFAULT '" + UserAgentHelper::SYSTEM_DEFAULT_DATABASE + "', " +
-                                     ULTRAPRIVACY + " INTEGER DEFAULT 0, " +
-                                     ULTRALIST + " INTEGER DEFAULT 0, " +
-                                     EASYPRIVACY + " INTEGER DEFAULT 0, " +
-                                     EASYLIST + " INTEGER DEFAULT 0, " +
-                                     FANBOYS_ANNOYANCE_LIST + " INTEGER DEFAULT 0, " +
-                                     ZOOM_FACTOR + " INTEGER DEFAULT 0, " +
-                                     CUSTOM_ZOOM_FACTOR + " REAL DEFAULT 1.0)");
+            createTableQuery.prepare(QLatin1String("CREATE TABLE ") + DOMAINS_TABLE + QLatin1String("(") +
+                                     ID + QLatin1String(" INTEGER PRIMARY KEY, ") +
+                                     DOMAIN_NAME + QLatin1String(" TEXT, ") +
+                                     JAVASCRIPT + QLatin1String(" INTEGER DEFAULT 0, ") +
+                                     LOCAL_STORAGE + QLatin1String(" INTEGER DEFAULT 0, ") +
+                                     DOM_STORAGE + QLatin1String(" INTEGER DEFAULT 0, ") +
+                                     USER_AGENT + QLatin1String(" TEXT DEFAULT '") + UserAgentHelper::SYSTEM_DEFAULT_DATABASE + QLatin1String("', ") +
+                                     ULTRAPRIVACY + QLatin1String(" INTEGER DEFAULT 0, ") +
+                                     ULTRALIST + QLatin1String(" INTEGER DEFAULT 0, ") +
+                                     EASYPRIVACY + QLatin1String(" INTEGER DEFAULT 0, ") +
+                                     EASYLIST + QLatin1String(" INTEGER DEFAULT 0, ") +
+                                     FANBOYS_ANNOYANCE_LIST + QLatin1String(" INTEGER DEFAULT 0, ") +
+                                     ZOOM_FACTOR + QLatin1String(" INTEGER DEFAULT 0, ") +
+                                     CUSTOM_ZOOM_FACTOR + QLatin1String(" REAL DEFAULT 1.0)"));
 
             // Execute the query.
             if (!createTableQuery.exec())
@@ -285,8 +311,11 @@ void DomainsDatabase::addDatabase()
                 qDebug().noquote().nospace() << "Error creating table:  " << domainsDatabase.lastError();
             }
 
+            // Create an update schema version query.
+            QSqlQuery updateSchemaVersionQuery(domainsDatabase);
+
             // Set the schema version.
-            domainsDatabase.exec("PRAGMA user_version = " + QString::number(SCHEMA_VERSION));
+            updateSchemaVersionQuery.exec(QLatin1String("PRAGMA user_version = ") + QString::number(SCHEMA_VERSION));
         }
     }
     else  // Opening the database failed.
@@ -314,35 +343,35 @@ void DomainsDatabase::addDomain(const QString &domainName, const int javaScriptI
     QSqlQuery addDomainSettingsQuery(domainsDatabase);
 
     // Prepare the query.
-    addDomainSettingsQuery.prepare("INSERT INTO " + DOMAINS_TABLE + " (" +
-                                    DOMAIN_NAME + ", " +
-                                    JAVASCRIPT + ", " +
-                                    LOCAL_STORAGE + ", " +
-                                    DOM_STORAGE + ", " +
-                                    USER_AGENT + ", " +
-                                    ULTRAPRIVACY + ", " +
-                                    ULTRALIST + ", " +
-                                    EASYPRIVACY + ", " +
-                                    EASYLIST + ", " +
-                                    FANBOYS_ANNOYANCE_LIST + ", " +
-                                    ZOOM_FACTOR + ", " +
-                                    CUSTOM_ZOOM_FACTOR + ") " +
-                                    "VALUES (:domain_name, :javascript, :local_storage, :dom_storage, :user_agent, :ultraprivacy, :ultralist, :easyprivacy, :easylist, :fanboys_annoyance_list, :zoom_factor, :custom_zoom_factor)"
-    );
+    addDomainSettingsQuery.prepare(QLatin1String("INSERT INTO ") + DOMAINS_TABLE + QLatin1String(" (") +
+                                    DOMAIN_NAME + QLatin1String(", ") +
+                                    JAVASCRIPT + QLatin1String(", ") +
+                                    LOCAL_STORAGE + QLatin1String(", ") +
+                                    DOM_STORAGE + QLatin1String(", ") +
+                                    USER_AGENT + QLatin1String(", ") +
+                                    ULTRAPRIVACY + QLatin1String(", ") +
+                                    ULTRALIST + QLatin1String(", ") +
+                                    EASYPRIVACY + QLatin1String(", ") +
+                                    EASYLIST + QLatin1String(", ") +
+                                    FANBOYS_ANNOYANCE_LIST + QLatin1String(", ") +
+                                    ZOOM_FACTOR + QLatin1String(", ") +
+                                    CUSTOM_ZOOM_FACTOR + QLatin1String(") ") +
+                                    QLatin1String("VALUES (:domain_name, :javascript, :local_storage, :dom_storage, :user_agent, :ultraprivacy, :ultralist, :easyprivacy, :easylist,") +
+                                    QLatin1String(":fanboys_annoyance_list, :zoom_factor, :custom_zoom_factor)"));
 
     // Bind the query values.
-    addDomainSettingsQuery.bindValue(":domain_name", domainName);
-    addDomainSettingsQuery.bindValue(":javascript", javaScriptInt);
-    addDomainSettingsQuery.bindValue(":local_storage", localStorageInt);
-    addDomainSettingsQuery.bindValue(":dom_storage", domStorageInt);
-    addDomainSettingsQuery.bindValue(":user_agent", userAgentDatabaseString);
-    addDomainSettingsQuery.bindValue(":ultraprivacy", ultraPrivacyInt);
-    addDomainSettingsQuery.bindValue(":ultralist", ultraListInt);
-    addDomainSettingsQuery.bindValue(":easyprivacy", easyPrivacyInt);
-    addDomainSettingsQuery.bindValue(":easylist", easyListInt);
-    addDomainSettingsQuery.bindValue(":fanboys_annoyance_list", fanboysAnnoyanceListInt);
-    addDomainSettingsQuery.bindValue(":zoom_factor", zoomFactorInt);
-    addDomainSettingsQuery.bindValue(":custom_zoom_factor", currentZoomFactorDouble);
+    addDomainSettingsQuery.bindValue(QLatin1String(":domain_name"), domainName);
+    addDomainSettingsQuery.bindValue(QLatin1String(":javascript"), javaScriptInt);
+    addDomainSettingsQuery.bindValue(QLatin1String(":local_storage"), localStorageInt);
+    addDomainSettingsQuery.bindValue(QLatin1String(":dom_storage"), domStorageInt);
+    addDomainSettingsQuery.bindValue(QLatin1String(":user_agent"), userAgentDatabaseString);
+    addDomainSettingsQuery.bindValue(QLatin1String(":ultraprivacy"), ultraPrivacyInt);
+    addDomainSettingsQuery.bindValue(QLatin1String(":ultralist"), ultraListInt);
+    addDomainSettingsQuery.bindValue(QLatin1String(":easyprivacy"), easyPrivacyInt);
+    addDomainSettingsQuery.bindValue(QLatin1String(":easylist"), easyListInt);
+    addDomainSettingsQuery.bindValue(QLatin1String(":fanboys_annoyance_list"), fanboysAnnoyanceListInt);
+    addDomainSettingsQuery.bindValue(QLatin1String(":zoom_factor"), zoomFactorInt);
+    addDomainSettingsQuery.bindValue(QLatin1String(":custom_zoom_factor"), currentZoomFactorDouble);
 
     // Execute the query.
     addDomainSettingsQuery.exec();
@@ -360,7 +389,7 @@ QSqlQuery DomainsDatabase::getDomainQuery(const QString &hostname)
     allDomainNamesQuery.setForwardOnly(true);
 
     // Prepare the query.
-    allDomainNamesQuery.prepare("SELECT " + ID + "," + DOMAIN_NAME + " FROM " + DOMAINS_TABLE);
+    allDomainNamesQuery.prepare(QLatin1String("SELECT ") + ID + QLatin1String(",") + DOMAIN_NAME + QLatin1String(" FROM ") + DOMAINS_TABLE);
 
     // Execute the query.
     allDomainNamesQuery.exec();
@@ -388,24 +417,24 @@ QSqlQuery DomainsDatabase::getDomainQuery(const QString &hostname)
     QString subdomain = hostname;
 
     // Check all the subdomains of the hostname.
-    while ((databaseId == -1) && subdomain.contains("."))  // Stop checking when a match is found or there are no more `.` in the hostname.
+    while ((databaseId == -1) && subdomain.contains(QLatin1String(".")))  // Stop checking when a match is found or there are no more `.` in the hostname.
     {
         // Check to see if the domain settings map contains the subdomain with a `*.` prepended.
-        if (domainSettingsMap.contains("*." + subdomain))
+        if (domainSettingsMap.contains(QLatin1String("*.") + subdomain))
         {
             // Get the database ID.
-            databaseId = domainSettingsMap.value("*." + subdomain);
+            databaseId = domainSettingsMap.value(QLatin1String("*.") + subdomain);
         }
 
         // Strip out the first subdomain.
-        subdomain = subdomain.section('.', 1);
+        subdomain = subdomain.section(QLatin1Char('.'), 1);
     }
 
     // Instantiate the domain lookup query.
     QSqlQuery domainLookupQuery(domainsDatabase);
 
     // Prepare the domain lookup query.
-    domainLookupQuery.prepare("SELECT * FROM " + DOMAINS_TABLE + " WHERE " + ID + " = " + QString::number(databaseId));
+    domainLookupQuery.prepare(QLatin1String("SELECT * FROM ") + DOMAINS_TABLE + QLatin1String(" WHERE ") + ID + QLatin1String(" = ") + QString::number(databaseId));
 
     // Execute the query.
     domainLookupQuery.exec();
