@@ -1,20 +1,20 @@
-/*
- * Copyright 2023-2024 Soren Stoutner <soren@stoutner.com>.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-FileCopyrightText: 2023-2024 Soren Stoutner <soren@stoutner.com>
  *
- * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc>.
+ * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc/>.
  *
- * Privacy Browser PC is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
  *
- * Privacy Browser PC is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 // Application headers.
@@ -136,7 +136,7 @@ void BookmarksDialog::deleteItems() const
     populateBookmarks();
 
     // Emit the bookmark updated signal to redraw the bookmarks in the menu and toolbar.
-    emit bookmarkUpdated();
+    Q_EMIT bookmarkUpdated();
 }
 
 void BookmarksDialog::populateBookmarks() const
@@ -258,7 +258,7 @@ void BookmarksDialog::refreshBookmarks() const
     populateBookmarks();
 
     // Emit the bookmark updated signal to redraw the bookmarks in the menu and toolbar.
-    emit bookmarkUpdated();
+    Q_EMIT bookmarkUpdated();
 }
 
 void BookmarksDialog::selectSubfolderContents(const QModelIndex &parentModelIndex) const
@@ -415,7 +415,7 @@ void BookmarksDialog::updateBookmarkFromTree(QStandardItem *modifiedStandardItem
     }
 
     // Emit the bookmark updated signal.
-    emit bookmarkUpdated();
+    Q_EMIT bookmarkUpdated();
 }
 
 void BookmarksDialog::updateSelection() const
