@@ -1,20 +1,20 @@
-/*
- * Copyright 2022-2024 Soren Stoutner <soren@stoutner.com>.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-FileCopyrightText: 2022-2024 Soren Stoutner <soren@stoutner.com>
  *
- * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc>.
+ * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc/>.
  *
- * Privacy Browser PC is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
  *
- * Privacy Browser PC is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 // Application headers.
@@ -70,20 +70,20 @@ bool cookieSortPredicate(const QNetworkCookie &leftHandCookie, const QNetworkCoo
         int rightHandDots = rightHandDomain.count(QLatin1Char('.'));
 
         // Get the top level domains.
-        leftHandTopLevelDomain = leftHandDomain.section('.', -1);
-        rightHandTopLevelDomain = rightHandDomain.section('.', -1);
+        leftHandTopLevelDomain = leftHandDomain.section(QLatin1Char('.'), -1);
+        rightHandTopLevelDomain = rightHandDomain.section(QLatin1Char('.'), -1);
 
         // Get the second level domains if they contain at least one dot.
         if (leftHandDots >= 1)
-            leftHandSecondLevelDomain = leftHandDomain.section('.', -2);
+            leftHandSecondLevelDomain = leftHandDomain.section(QLatin1Char('.'), -2);
         if (rightHandDots >= 1)
-            rightHandSecondLevelDomain = rightHandDomain.section('.', -2);
+            rightHandSecondLevelDomain = rightHandDomain.section(QLatin1Char('.'), -2);
 
         // Get the third level domains if they contain at least two dots.
         if (leftHandDots >= 2)
-            leftHandThirdLevelDomain = leftHandDomain.section('.', -3);
+            leftHandThirdLevelDomain = leftHandDomain.section(QLatin1Char('.'), -3);
         if (rightHandDots >= 2)
-            rightHandThirdLevelDomain = rightHandDomain.section('.', -3);
+            rightHandThirdLevelDomain = rightHandDomain.section(QLatin1Char('.'), -3);
 
         // Check to see if the top level domains are the same.  Segments, like third level domains, that don't exist will be blank, which will cause the sorting to group similar domains.
         if (leftHandTopLevelDomain == rightHandTopLevelDomain)
@@ -167,7 +167,7 @@ CookiesDialog::CookiesDialog(std::list<QNetworkCookie> *originalCookieListPointe
     cookieListPointer->sort(cookieSortPredicate);
 
     // Create the current domain string.
-    QString currentDomainString = "";
+    QString currentDomainString = QLatin1String("");
 
     // Create the current domain item pointer.
     QStandardItem *currentDomainItemPointer;
@@ -201,13 +201,13 @@ CookiesDialog::CookiesDialog(std::list<QNetworkCookie> *originalCookieListPointe
         QList<QStandardItem*> cookieItemList;
 
         // Create the cookie items.
-        QStandardItem *nameItemPointer = new QStandardItem(QString(cookie.name()));
+        QStandardItem *nameItemPointer = new QStandardItem(QLatin1String(cookie.name()));
         QStandardItem *durableItemPointer = new QStandardItem(isDurable ? i18n("yes") : i18n("no"));
         QStandardItem *pathItemPointer = new QStandardItem(cookie.path());
         QStandardItem *expirationDateItemPointer = new QStandardItem(cookie.expirationDate().toString());
         QStandardItem *isHttpOnlyItemPointer = new QStandardItem(cookie.isHttpOnly() ? i18n("yes") : i18n("no"));
         QStandardItem *isSecureItemPointer = new QStandardItem(cookie.isSecure() ? i18n("yes") : i18n("no"));
-        QStandardItem *valueItemPointer = new QStandardItem(QString(cookie.value()));
+        QStandardItem *valueItemPointer = new QStandardItem(QLatin1String(cookie.value()));
 
         // Populate the cookie standard item list.
         cookieItemList.append(nameItemPointer);
@@ -259,7 +259,7 @@ CookiesDialog::CookiesDialog(std::list<QNetworkCookie> *originalCookieListPointe
                                                                     QDialogButtonBox::ActionRole);
 
     // Set the button icons.
-    durableCookiesButtonPointer->setIcon(QIcon::fromTheme("view-visible", QIcon::fromTheme(QLatin1String("appointment-new"))));
+    durableCookiesButtonPointer->setIcon(QIcon::fromTheme(QLatin1String("view-visible"), QIcon::fromTheme(QLatin1String("appointment-new"))));
 
     // Connect the buttons.
     connect(addCookieButtonPointer, SIGNAL(clicked()), this, SLOT(showAddCookieDialog()));
@@ -300,7 +300,7 @@ CookiesDialog::CookiesDialog(std::list<QNetworkCookie> *originalCookieListPointe
 void CookiesDialog::addCookieFromDialog(const QNetworkCookie &cookie, const bool &isDurable) const
 {
     // Add the cookie to the cookie list and the cookie store.
-    emit addCookie(cookie);
+    Q_EMIT addCookie(cookie);
 
     // Get the new domain string.
     QString newDomain = cookie.domain();
@@ -332,15 +332,15 @@ void CookiesDialog::addCookieFromDialog(const QNetworkCookie &cookie, const bool
         int newDomainDots = newDomain.count(QLatin1Char('.'));
 
         // Get the new top level domain.
-        newDomainTopLevelDomain = newDomain.section('.', -1);
+        newDomainTopLevelDomain = newDomain.section(QLatin1Char('.'), -1);
 
         // Get the new second level domain if it contains at least one dot.
         if (newDomainDots >= 1)
-            newDomainSecondLevelDomain = newDomain.section('.', -2);
+            newDomainSecondLevelDomain = newDomain.section(QLatin1Char('.'), -2);
 
         // Get the new third level domain if it contains at least two dots.
         if (newDomainDots >= 2)
-            newDomainThirdLevelDomain = newDomain.section('.', -3);
+            newDomainThirdLevelDomain = newDomain.section(QLatin1Char('.'), -3);
 
         // Create while loop trackers.
         bool locationFound = false;
@@ -360,15 +360,15 @@ void CookiesDialog::addCookieFromDialog(const QNetworkCookie &cookie, const bool
             int currentDomainDots = currentDomain.count(QLatin1Char('.'));
 
             // Get the current top level domain.
-            currentDomainTopLevelDomain = currentDomain.section('.', -1);
+            currentDomainTopLevelDomain = currentDomain.section(QLatin1Char('.'), -1);
 
             // Get the current second level domain if it contains at least one dot.
             if (currentDomainDots >= 1)
-                currentDomainSecondLevelDomain = currentDomain.section('.', -2);
+                currentDomainSecondLevelDomain = currentDomain.section(QLatin1Char('.'), -2);
 
             // Get the current third level domain if it contains at least two dots.
             if (currentDomainDots >= 2)
-                currentDomainThirdLevelDomain = currentDomain.section('.', -3);
+                currentDomainThirdLevelDomain = currentDomain.section(QLatin1Char('.'), -3);
 
             // Check to see if the new domain should be inserted after the current domain.
             // Segments, like third level domains, that do not exist will be blank, which will cause the sorting to group similar domains.
@@ -398,7 +398,7 @@ void CookiesDialog::addCookieFromDialog(const QNetworkCookie &cookie, const bool
     }
 
     // Get strings for the new cookie name and path (used later in the placement of the row).
-    QString newCookieName = QString(cookie.name());
+    QString newCookieName = QLatin1String(cookie.name());
     QString newCookiePath = QString(cookie.path());
 
     // Create a cookie item list.
@@ -406,12 +406,12 @@ void CookiesDialog::addCookieFromDialog(const QNetworkCookie &cookie, const bool
 
     // Create the cookie items.
     QStandardItem *nameItemPointer = new QStandardItem(newCookieName);
-    QStandardItem *durableItemPointer = new QStandardItem(QString(isDurable ? i18n("yes") : i18n("no")));
+    QStandardItem *durableItemPointer = new QStandardItem(isDurable ? i18n("yes") : i18n("no"));
     QStandardItem *pathItemPointer = new QStandardItem(newCookiePath);
-    QStandardItem *expirationDateItemPointer = new QStandardItem(QString(cookie.expirationDate().toString()));
-    QStandardItem *isHttpOnlyItemPointer = new QStandardItem(QString(cookie.isHttpOnly() ? i18n("yes") : i18n("no")));
-    QStandardItem *isSecureItemPointer = new QStandardItem(QString(cookie.isSecure() ? i18n("yes") : i18n("no")));
-    QStandardItem *valueItemPointer = new QStandardItem(QString(cookie.value()));
+    QStandardItem *expirationDateItemPointer = new QStandardItem(cookie.expirationDate().toString());
+    QStandardItem *isHttpOnlyItemPointer = new QStandardItem(cookie.isHttpOnly() ? i18n("yes") : i18n("no"));
+    QStandardItem *isSecureItemPointer = new QStandardItem(cookie.isSecure() ? i18n("yes") : i18n("no"));
+    QStandardItem *valueItemPointer = new QStandardItem(QLatin1String(cookie.value()));
 
     // Populate the cookie item list.
     cookieItemList.append(nameItemPointer);
@@ -507,7 +507,7 @@ void CookiesDialog::deleteCookie(const QModelIndex &modelIndex, const bool &dele
         treeModelPointer->removeRow(modelIndex.row(), modelIndex.parent());
 
         // Delete the cookie from the cookie list and cookie store.
-        emit deleteCookie(cookieToDelete);
+        Q_EMIT deleteCookie(cookieToDelete);
 
         // Delete the cookie from the durable cookies database.
         if (isDurable)
@@ -557,7 +557,7 @@ void CookiesDialog::deleteCookieFromDatabase(const QNetworkCookie &cookie) const
             QModelIndex nameModelIndex = nameItemPointer->index();
 
             // Check to see if the name and the path match.
-            if ((nameModelIndex.data().toString() == cookie.name()) && (nameModelIndex.siblingAtColumn(2).data().toString() == cookie.path()))
+            if ((nameModelIndex.data().toString() == QLatin1String(cookie.name())) && (nameModelIndex.siblingAtColumn(2).data().toString() == cookie.path()))
             {
                 // Set the current index.
                 treeSelectionModelPointer->setCurrentIndex(nameModelIndex, QItemSelectionModel::ClearAndSelect);
@@ -591,7 +591,7 @@ void CookiesDialog::deleteCookieFromDialog(const QNetworkCookie &cookie) const
         treeModelPointer->removeRow(parentIndex.row(), parentIndex.parent());
 
     // Delete the cookie from the cookie list and cookie store.
-    emit deleteCookie(cookie);
+    Q_EMIT deleteCookie(cookie);
 }
 
 void CookiesDialog::showAddCookieDialog()
@@ -642,7 +642,7 @@ void CookiesDialog::showDeleteAllMessageBox() const
         if (deleteDurableCookiesCheckBox.isChecked())  // Delete everything.
         {
             // Delete all the cookies.
-            emit deleteAllCookies();
+            Q_EMIT deleteAllCookies();
 
             // Clear the tree model.
             treeModelPointer->clear();
