@@ -1,20 +1,20 @@
-/*
- * Copyright 2022-2024 Soren Stoutner <soren@stoutner.com>.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-FileCopyrightText: 2022-2025 Soren Stoutner <soren@stoutner.com>
  *
  * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc/>.
  *
- * Privacy Browser PC is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
  *
- * Privacy Browser PC is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 // Application headers.
@@ -87,10 +87,14 @@ DomainSettingsDialog::DomainSettingsDialog(QWidget *parentWidgetPointer, const i
     customZoomFactorSpinBoxPointer = domainSettingsDialogUi.customZoomFactorSpinBox;
     QPushButton *addDomainButtonPointer = domainSettingsDialogUi.addDomainButton;
     deleteDomainButtonPointer = domainSettingsDialogUi.deleteDomainButton;
+    deleteAllDomainsButtonPointer = domainSettingsDialogUi.deleteAllDomainsButton;
     QDialogButtonBox *dialogButtonBoxPointer = domainSettingsDialogUi.dialogButtonBox;
     applyButtonPointer = dialogButtonBoxPointer->button(QDialogButtonBox::StandardButton::Apply);
     resetButtonPointer = dialogButtonBoxPointer->button(QDialogButtonBox::StandardButton::Reset);
 
+    // Set the button icons that require a fallback icon.
+    deleteAllDomainsButtonPointer->setIcon(QIcon::fromTheme(QLatin1String("albumfolder-user-trash"), QIcon::fromTheme(QLatin1String("list-remove"))));
+
     // Create a table model.
     domainsTableModelPointer = new QSqlTableModel(nullptr, QSqlDatabase::database(DomainsDatabase::CONNECTION_NAME));
 
@@ -125,13 +129,13 @@ DomainSettingsDialog::DomainSettingsDialog(QWidget *parentWidgetPointer, const i
     highlightedPalette = defaultPalette;
 
     // Get the default highlight color.
-    QColor highlightColor = defaultPalette.color(QPalette::Highlight);
+    QColor alphaHighlightColor = defaultPalette.color(QPalette::Highlight);
 
     // Set the highlight color to be partially transparent.
-    highlightColor.setAlpha(64);
+    alphaHighlightColor.setAlpha(64);
 
     // Set highlighted background color.
-    highlightedPalette.setColor(QPalette::Window, highlightColor);
+    highlightedPalette.setColor(QPalette::Window, alphaHighlightColor);
 
     // Setup the dialog according to the start type.
     switch (startType)
@@ -180,6 +184,7 @@ DomainSettingsDialog::DomainSettingsDialog(QWidget *parentWidgetPointer, const i
     // Connect the buttons.
     connect(addDomainButtonPointer, SIGNAL(clicked()), this, SLOT(showAddMessageBox()));
     connect(deleteDomainButtonPointer, SIGNAL(clicked()), this, SLOT(showDeleteMessageBox()));
+    connect(deleteAllDomainsButtonPointer, SIGNAL(clicked()), this, SLOT(showDeleteAllMessageBox()));
     connect(resetButtonPointer, SIGNAL(clicked()), this, SLOT(reset()));
     connect(dialogButtonBoxPointer, SIGNAL(accepted()), this, SLOT(ok()));
     connect(applyButtonPointer, SIGNAL(clicked()), this, SLOT(apply()));
@@ -214,7 +219,7 @@ void DomainSettingsDialog::apply() const
     updateButtons();
 
     // Emit the domain settings updated signal.
-    emit domainSettingsUpdated();
+    Q_EMIT domainSettingsUpdated();
 }
 
 void DomainSettingsDialog::cancel()
@@ -295,6 +300,19 @@ void DomainSettingsDialog::domainSelected(const QModelIndex &modelIndex) const
     // Populate the zoom factor combo box.
     zoomFactorComboBoxPointer->setCurrentIndex(zoomFactorComboBoxIndex);
 
+    // Get the combo box palette.
+    QPalette comboBoxPalette = zoomFactorComboBoxPointer->palette();
+
+    // Get the combo box window color.
+    QColor comboBoxWindowColor = comboBoxPalette.color(QPalette::Window);
+
+    // Set the combo box window color back to the palette.  This makes the system think the palette has changed.
+    comboBoxPalette.setColor(QPalette::Window, comboBoxWindowColor);
+
+    // Explicitly set the combo box palette.  Because the system thinks the palette has been changed, and because the combo box palette is being explicitly set,
+    // the system will not propagate the highlighted palette from the widget pointer palette down to the combo box.  <https://redmine.stoutner.com/issues/1252>
+    zoomFactorComboBoxPointer->setPalette(comboBoxPalette);
+
     // Populate the custom zoom factor spin box according to the zoom factor combo box.
     if (zoomFactorComboBoxIndex == 0)  // System default zoom factor is selected.
     {
@@ -403,7 +421,7 @@ void DomainSettingsDialog::ok()
     domainsTableModelPointer->submitAll();
 
     // Emit the domain settings updated signal.
-    emit domainSettingsUpdated();
+    Q_EMIT domainSettingsUpdated();
 
     // Close the dialog.
     accept();
@@ -581,6 +599,19 @@ void DomainSettingsDialog::populateLabel(const int label) const
         }
     }
 
+    // Get the combo box palette.
+    QPalette comboBoxPalette = comboBoxPointer->palette();
+
+    // Get the combo box window color.
+    QColor comboBoxWindowColor = comboBoxPalette.color(QPalette::Window);
+
+    // Set the combo box window color back to the palette.  This makes the system think the palette has changed.
+    comboBoxPalette.setColor(QPalette::Window, comboBoxWindowColor);
+
+    // Explicitly set the combo box palette.  Because the system thinks the palette has been changed, and because the combo box palette is being explicitly set,
+    // the system will not propagate the highlighted palette from the widget pointer palette down to the combo box.  <https://redmine.stoutner.com/issues/1252>
+    comboBoxPointer->setPalette(comboBoxPalette);
+
     // Populate the label and widget palette according to the currently selected combo box index.
     switch (comboBoxPointer->currentIndex())
     {
@@ -594,7 +625,6 @@ void DomainSettingsDialog::populateLabel(const int label) const
 
             // Reset the palette.
             widgetPointer->setPalette(defaultPalette);
-
             break;
         }
 
@@ -603,9 +633,8 @@ void DomainSettingsDialog::populateLabel(const int label) const
             // Set the enabled bold text.
             labelPointer->setText(enabledBoldString);
 
-            // Set the palette.
+            // Set the widget palette.
             widgetPointer->setPalette(highlightedPalette);
-
             break;
         }
 
@@ -614,9 +643,8 @@ void DomainSettingsDialog::populateLabel(const int label) const
             // Set the disabled bold text.
             labelPointer->setText(disabledBoldString);
 
-            // Set the palette.
+            // Set the widget palette.
             widgetPointer->setPalette(highlightedPalette);
-
             break;
         }
     }
@@ -636,9 +664,22 @@ void DomainSettingsDialog::populateUserAgentLabel(const QString &userAgentName)
     else
     {
         // Display the user agent name in bold.
-        userAgentLabelPointer->setText("<strong>" + userAgentName + "</strong>");
+        userAgentLabelPointer->setText(QLatin1String("<strong>") + userAgentName + QLatin1String("</strong>"));
 
-        // Set the palette.
+        // Get the combo box palette.
+        QPalette comboBoxPalette = userAgentComboBoxPointer->palette();
+
+        // Get the combo box window color.
+        QColor comboBoxWindowColor = comboBoxPalette.color(QPalette::Window);
+
+        // Set the combo box window color back to the palette.  This makes the system think the palette has changed.
+        comboBoxPalette.setColor(QPalette::Window, comboBoxWindowColor);
+
+        // Explicitly set the combo box palette.  Because the system thinks the palette has been changed, and because the combo box palette is being explicitly set,
+        // the system will not propagate the highlighted palette from the widget pointer palette down to the combo box.  <https://redmine.stoutner.com/issues/1252>
+        userAgentComboBoxPointer->setPalette(comboBoxPalette);
+
+        // Set the widget palette.
         userAgentWidgetPointer->setPalette(highlightedPalette);
     }
 }
@@ -691,35 +732,81 @@ void DomainSettingsDialog::showAddMessageBox()
         updateButtons();
 
         // Emit the domain settings updated signal.
-        emit domainSettingsUpdated();
+        Q_EMIT domainSettingsUpdated();
+    }
+}
+
+void DomainSettingsDialog::showDeleteAllMessageBox() const
+{
+    // Instantiate a delete all message box.
+    QMessageBox deleteAllMessageBox;
+
+    // Set the icon.
+    deleteAllMessageBox.setIcon(QMessageBox::Warning);
+
+    // Set the window title.
+    deleteAllMessageBox.setWindowTitle(i18nc("Delete all domains dialog title", "Delete All Domains"));
+
+    // Set the text.
+    deleteAllMessageBox.setText(i18nc("Delete all domains dialog main message", "Delete all domains?"));
+
+    // Set the informative test.
+    deleteAllMessageBox.setInformativeText(i18nc("Delete all domains dialog secondary message", "This action cannot be undone."));
+
+    // Set the standard buttons.
+    deleteAllMessageBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+
+    // Set the default button.
+    deleteAllMessageBox.setDefaultButton(QMessageBox::No);
+
+    // Display the dialog and capture the return value.
+    int returnValue = deleteAllMessageBox.exec();
+
+    // Delete all domains if instructed.
+    if (returnValue == QMessageBox::Yes)
+    {
+        // Get the count of all rows.
+        int rowCount = domainsTableModelPointer->rowCount();
+
+        // Delete all the rows, starting with 0.
+        domainsTableModelPointer->removeRows(0, rowCount);
+
+        // Submit all pending changes.
+        domainsTableModelPointer->submitAll();
+
+        // Update the buttons.
+        updateButtons();
+
+        // Emit the domain settings updated signal.
+        Q_EMIT domainSettingsUpdated();
     }
 }
 
 void DomainSettingsDialog::showDeleteMessageBox() const
 {
-    // Instantiate a delete dialog message box.
-    QMessageBox deleteDialogMessageBox;
+    // Instantiate a delete message box.
+    QMessageBox deleteMessageBox;
 
     // Set the icon.
-    deleteDialogMessageBox.setIcon(QMessageBox::Warning);
+    deleteMessageBox.setIcon(QMessageBox::Warning);
 
     // Set the window title.
-    deleteDialogMessageBox.setWindowTitle(i18nc("Delete domain dialog title", "Delete Domain"));
+    deleteMessageBox.setWindowTitle(i18nc("Delete domain dialog title", "Delete Domain"));
 
     // Set the text.
-    deleteDialogMessageBox.setText(i18nc("Delete domain dialog main message", "Delete the current domain?"));
+    deleteMessageBox.setText(i18nc("Delete domain dialog main message", "Delete the current domain?"));
 
     // Set the informative text.
-    deleteDialogMessageBox.setInformativeText(i18nc("Delete domain dialog secondary message", "Doing so will also save any pending changes that have been made to other domains."));
+    deleteMessageBox.setInformativeText(i18nc("Delete domain dialog secondary message", "Doing so will also save any pending changes that have been made to other domains."));
 
     // Set the standard buttons.
-    deleteDialogMessageBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+    deleteMessageBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
 
     // Set the default button.
-    deleteDialogMessageBox.setDefaultButton(QMessageBox::No);
+    deleteMessageBox.setDefaultButton(QMessageBox::No);
 
     // Display the dialog and capture the return value.
-    int returnValue = deleteDialogMessageBox.exec();
+    int returnValue = deleteMessageBox.exec();
 
     // Delete the domain if instructed.
     if (returnValue == QMessageBox::Yes)
@@ -756,7 +843,7 @@ void DomainSettingsDialog::showDeleteMessageBox() const
         updateButtons();
 
         // Emit the domain settings updated signal.
-        emit domainSettingsUpdated();
+        Q_EMIT domainSettingsUpdated();
     }
 }
 
@@ -786,9 +873,15 @@ void DomainSettingsDialog::ultraPrivacyChanged(const int newIndex) const
 
 void DomainSettingsDialog::updateButtons() const
 {
+    // Get
+    bool atLeastOneDomainSettingExists = domainsTableModelPointer->rowCount() > 0;
+
     // Update the delete button status.
     deleteDomainButtonPointer->setEnabled(domainsSelectionModelPointer->hasSelection());
 
+    // Update the delete all button status.
+    deleteAllDomainsButtonPointer->setEnabled(atLeastOneDomainSettingExists);
+
     // Update the reset button status.
     resetButtonPointer->setEnabled(domainsTableModelPointer->isDirty());
 
@@ -796,7 +889,7 @@ void DomainSettingsDialog::updateButtons() const
     applyButtonPointer->setEnabled(domainsTableModelPointer->isDirty());
 
     // Display the domain settings if there is at least one domain.
-    domainSettingsWidgetPointer->setVisible(domainsTableModelPointer->rowCount() > 0);
+    domainSettingsWidgetPointer->setVisible(atLeastOneDomainSettingExists);
 }
 
 void DomainSettingsDialog::updateDomStorageStatus() const
