@@ -1,20 +1,20 @@
-/*
- * Copyright 2022, 2024 Soren Stoutner <soren@stoutner.com>.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-FileCopyrightText: 2022, 2024 Soren Stoutner <soren@stoutner.com>
  *
  * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc/>.
  *
- * Privacy Browser PC is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
  *
- * Privacy Browser PC is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef DOMAIN_SETTINGS_DIALOG_H
@@ -46,7 +46,7 @@ public:
     static const int ADD_DOMAIN;
     static const int EDIT_DOMAIN;
 
-signals:
+Q_SIGNALS:
     void domainSettingsUpdated() const;
 
 private Q_SLOTS:
@@ -65,6 +65,7 @@ private Q_SLOTS:
     void ok();
     void reset() const;
     void showAddMessageBox();
+    void showDeleteAllMessageBox() const;
     void showDeleteMessageBox() const;
     void ultraListChanged(const int newIndex) const;
     void ultraPrivacyChanged(const int newIndex) const;
@@ -86,6 +87,7 @@ private:
     QPushButton *applyButtonPointer;
     QDoubleSpinBox *customZoomFactorSpinBoxPointer;
     QPalette defaultPalette;
+    QPushButton *deleteAllDomainsButtonPointer;
     QPushButton *deleteDomainButtonPointer;
     QWidget *domStorageWidgetPointer;
     QComboBox *domStorageComboBoxPointer;
