@@ -1,20 +1,20 @@
-/*
- * Copyright 2022-2024 Soren Stoutner <soren@stoutner.com>.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-FileCopyrightText: 2022-2024 Soren Stoutner <soren@stoutner.com>
  *
- * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc>.
+ * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc/>.
  *
- * Privacy Browser PC is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
  *
- * Privacy Browser PC is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 // Application headers.
@@ -76,9 +76,9 @@ SaveDialog::SaveDialog(QWidget *parentWidgetPointer, QUrl &url, QString &mimeTyp
     mimeGraphicsScenePointer->addPixmap(mimeTypeIcon.pixmap(64, 64));
 
     // Populate the labels.
-    urlLabelPointer->setText("<b>" + downloadUrl.toString() + "</b>");
-    filetypeLabelPointer->setText("<b>" + mimeType.comment() + "</b>");
-    mimeTypeLabelPointer->setText("<b>" + mimeTypeString + "</b>");
+    urlLabelPointer->setText(QLatin1String("<b>") + downloadUrl.toString() + QLatin1String("</b>"));
+    filetypeLabelPointer->setText(QLatin1String("<b>") + mimeType.comment() + QLatin1String("</b>"));
+    mimeTypeLabelPointer->setText(QLatin1String("<b>") + mimeTypeString + QLatin1String("</b>"));
 
     // Populate the download size label.
     if (totalBytes == -1)  // The file size is unknown.
@@ -114,7 +114,7 @@ SaveDialog::SaveDialog(QWidget *parentWidgetPointer, QUrl &url, QString &mimeTyp
 void SaveDialog::showFilePicker()
 {
     // Show the file picker dialog.
-    emit useNativeKdeDownloader(downloadUrl, suggestedFileName);
+    Q_EMIT useNativeKdeDownloader(downloadUrl, suggestedFileName);
 
     // Close the dialog.
     reject();
