@@ -1,20 +1,20 @@
-/*
- * Copyright 2024 Soren Stoutner <soren@stoutner.com>.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-FileCopyrightText: 2024 Soren Stoutner <soren@stoutner.com>
  *
- * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc>.
+ * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc/>.
  *
- * Privacy Browser PC is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
  *
- * Privacy Browser PC is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 // Application headers.
@@ -82,8 +82,8 @@ SettingsDialog::SettingsDialog(QWidget *parentWidgetPointer, KCoreConfigSkeleton
     // Connect the download directory directory browse button.
     connect(browseButtonPointer, SIGNAL(clicked()), this, SLOT(showDownloadDirectoryBrowseDialog()));
 
-    // Create a dictionaries QDir from the `QTWEBENGINE_DICTIONARIES_PATH` environment variable.
-    QDir dictionariesDir = QDir(qEnvironmentVariable("QTWEBENGINE_DICTIONARIES_PATH"));
+    // Create a dictionaries QDir from the `QTWEBENGINE_DICTIONARIES_PATH` environment variable, defaulting to `/usr/share/hunspell-bdic` if no environment variable is set.
+    QDir dictionariesDir = QDir(qEnvironmentVariable("QTWEBENGINE_DICTIONARIES_PATH", QLatin1String("/usr/share/hunspell-bdic")));
 
     // Get a dictionaries string list.
     QStringList dictionariesStringList = dictionariesDir.entryList(QStringList(QLatin1String("*.bdic")), QDir::Files | QDir::NoSymLinks);
@@ -95,7 +95,7 @@ SettingsDialog::SettingsDialog(QWidget *parentWidgetPointer, KCoreConfigSkeleton
     QStringList enabledSpellCheckLanguagesList = Settings::spellCheckLanguages();
 
     // Add each dictionary to the spell check list widget.
-    foreach (QString dictionaryString, dictionariesStringList)
+    for (QString dictionaryString : dictionariesStringList)
     {
         // Create a new list widget item pointer.
         QListWidgetItem *listWidgetItemPointer = new QListWidgetItem();
@@ -120,7 +120,7 @@ SettingsDialog::SettingsDialog(QWidget *parentWidgetPointer, KCoreConfigSkeleton
     QString settingsIconString;
 
     // Get a settings icon that matches the theme.
-    if (QIcon::hasThemeIcon("breeze-settings"))
+    if (QIcon::hasThemeIcon(QLatin1String("breeze-settings")))
     {
         // KDE uses breeze-settings.
         settingsIconString = QLatin1String("breeze-settings");
@@ -167,7 +167,7 @@ SettingsDialog::SettingsDialog(QWidget *parentWidgetPointer, KCoreConfigSkeleton
                 QString languageString = languageCheckBoxPointer->text();
 
                 // Remove all instances of `&`, which may have been added automatically when creating the check box text.
-                languageString.remove(QChar('&'));
+                languageString.remove(QLatin1Char('&'));
 
                 // Add the language string to the list.
                 newSpellCheckLanguages.append(languageString);
@@ -184,7 +184,7 @@ SettingsDialog::SettingsDialog(QWidget *parentWidgetPointer, KCoreConfigSkeleton
             coreConfigSkeletonPointer->save();
 
             // Emit the spell check languages updated signal.
-            emit spellCheckLanguagesUpdated();
+            Q_EMIT spellCheckLanguagesUpdated();
         }
     };
 
@@ -209,7 +209,7 @@ void SettingsDialog::showDownloadDirectoryBrowseDialog()
     if (newDownloadDirectory == QStandardPaths::writableLocation(QStandardPaths::DownloadLocation))  // The default download location was selected.
     {
         // Populate the download location with the default text.
-        downloadDirectoryComboBoxPointer->setCurrentText("System Download Directory");
+        downloadDirectoryComboBoxPointer->setCurrentText(QLatin1String("System Download Directory"));
     }
     else if (newDownloadDirectory != QStringLiteral(""))  // A different directory was selected.
     {
