@@ -1,20 +1,20 @@
-/*
- * Copyright 2024 Soren Stoutner <soren@stoutner.com>.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-FileCopyrightText: 2024 Soren Stoutner <soren@stoutner.com>
  *
  * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc/>.
  *
- * Privacy Browser PC is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
  *
- * Privacy Browser PC is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Privacy Browser PC.  If not, see <https://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 // Application headers.
@@ -564,7 +564,7 @@ bool FilterListHelper::checkDomain(QWebEngineUrlRequestInfo &urlRequestInfo, Req
     else if (entryStructPointer->domain == FilterOptionDisposition::Apply)  // Block requests from listed domains.
     {
         // Check each domain.
-        foreach (QString blockedDomain, entryStructPointer->domainList)
+        for (QString blockedDomain : entryStructPointer->domainList)
         {
             // Check if the request came from a blocked domain.
             if (requestStructPointer->firstPartyHost.endsWith(blockedDomain))
@@ -580,7 +580,7 @@ bool FilterListHelper::checkDomain(QWebEngineUrlRequestInfo &urlRequestInfo, Req
         bool blockDomain = true;
 
         // Check each overridden domain.
-        foreach (QString overriddenDomain, entryStructPointer->domainList)
+        for (QString overriddenDomain : entryStructPointer->domainList)
         {
             // Check if the request came from an overridden domain.
             if (requestStructPointer->firstPartyHost.endsWith(overriddenDomain))
@@ -918,7 +918,7 @@ FilterListStruct* FilterListHelper::populateFilterList(const QString &filterList
                 QStringList appliedFilterOptionsList;
 
                 // Populate the applied filter options list.
-                foreach (QString filterOption, originalFilterOptionsList)
+                for (QString filterOption : originalFilterOptionsList)
                 {
                     // Only add filter options that are handled by Privacy Browser.  <https://help.adblockplus.org/hc/en-us/articles/360062733293-How-to-write-filters>
                     // `csp` specifies a Content Security Policy, which isn't handled by Privacy Browser.
@@ -951,7 +951,7 @@ FilterListStruct* FilterListHelper::populateFilterList(const QString &filterList
                 OverrideStruct overrideStruct;
 
                 // Populate the filter options entries.
-                foreach (QString filterOption, appliedFilterOptionsList)
+                for (QString filterOption : appliedFilterOptionsList)
                 {
                     // Parse the filter options.
                     if (filterOption.startsWith(QLatin1String("domain=")))  // Domain.
