@@ -1,20 +1,20 @@
-/*
- * Copyright 2023-2024 Soren Stoutner <soren@stoutner.com>.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-FileCopyrightText: 2023-2024 Soren Stoutner <soren@stoutner.com>
  *
- * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc>.
+ * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc/>.
  *
- * Privacy Browser PC is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
  *
- * Privacy Browser PC is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 // Application headers.
@@ -54,7 +54,7 @@ void DraggableTreeView::dropEvent(QDropEvent *dropEvent)
     int dropPosition = dropIndicatorPosition();
 
     // Get the drop model index.
-    QModelIndex dropModelIndex = indexAt(dropEvent->pos());
+    QModelIndex dropModelIndex = indexAt(dropEvent->position().toPoint());
 
     // Create a previous parent folder ID standard C++ list (which can be sorted and from which duplicates can be removed).
     std::list<double> *previousParentFolderIdListPointer = new std::list<double>;
@@ -228,7 +228,7 @@ void DraggableTreeView::dropEvent(QDropEvent *dropEvent)
         BookmarksDatabase::updateFolderContentsDisplayOrder(parentFolderId);
 
     // Emit the bookmarks moved signal.
-    emit bookmarksMoved();
+    Q_EMIT bookmarksMoved();
 }
 
 QList<int>* DraggableTreeView::getRootSelectedDatabaseIds(QList<int> *selectedDatabaseIdsPointer) const
