@@ -1,20 +1,20 @@
-/*
- * Copyright 2022-2024 Soren Stoutner <soren@stoutner.com>.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-FileCopyrightText: 2022-2025 Soren Stoutner <soren@stoutner.com>
  *
  * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc/>.
  *
- * Privacy Browser PC is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
  *
- * Privacy Browser PC is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 // Application headers.
@@ -22,6 +22,7 @@
 #include "PrivacyWebEngineView.h"
 #include "PrivacyWebEnginePage.h"
 #include "Settings.h"
+#include "TemporaryWebEngineView.h"
 #include "ui_HttpAuthenticationDialog.h"
 #include "databases/CookiesDatabase.h"
 #include "databases/DomainsDatabase.h"
@@ -30,7 +31,7 @@
 #include "interceptors/UrlRequestInterceptor.h"
 #include "windows/BrowserWindow.h"
 
-// Qt toolkit headers.
+// Qt framework headers.
 #include <QContextMenuEvent>
 #include <QMenu>
 
@@ -40,6 +41,9 @@ PrivacyWebEngineView::PrivacyWebEngineView(QWidget *parentWidgetPointer) : QWebE
     // Create an off-the-record profile (the default when no profile name is specified).
     webEngineProfilePointer = new QWebEngineProfile(QLatin1String(""));
 
+    // Disable the HTTP cache.
+    webEngineProfilePointer->setHttpCacheType(QWebEngineProfile::NoCache);
+
     // Create a WebEngine page.
     PrivacyWebEnginePage *privacyWebEnginePagePointer = new PrivacyWebEnginePage(webEngineProfilePointer);
 
@@ -56,7 +60,7 @@ PrivacyWebEngineView::PrivacyWebEngineView(QWidget *parentWidgetPointer) : QWebE
     webEngineProfilePointer->setUrlRequestInterceptor(urlRequestInterceptorPointer);
 
     // Connect the URL request interceptor signals.
-    connect(urlRequestInterceptorPointer, SIGNAL(applyDomainSettings(const QString&)), this, SLOT(applyDomainSettingsWithoutReloading(const QString&)));
+    connect(urlRequestInterceptorPointer, SIGNAL(applyDomainSettings(const QUrl&, const bool)), this, SLOT(applyDomainSettings(const QUrl&, const bool)));
     connect(urlRequestInterceptorPointer, SIGNAL(newMainFrameResource()), this, SLOT(clearRequestsList()));
     connect(urlRequestInterceptorPointer, SIGNAL(displayHttpPingDialog(const QString&)), this, SLOT(displayHttpPingDialog(const QString&)));
     connect(urlRequestInterceptorPointer, SIGNAL(requestProcessed(RequestStruct*)), this, SLOT(storeRequest(RequestStruct*)));
@@ -66,6 +70,9 @@ PrivacyWebEngineView::PrivacyWebEngineView(QWidget *parentWidgetPointer) : QWebE
 
     // Store the link URL whenever a link is hovered.
     connect(privacyWebEnginePagePointer, SIGNAL(linkHovered(const QString)), this, SLOT(saveHoveredLink(const QString)));
+
+    // Store the URL when it changes.
+    connect(this, SIGNAL(urlChanged(const QUrl&)), this, SLOT(storeUpdatedUrl(const QUrl&)));
 }
 
 void PrivacyWebEngineView::addCookieToList(const QNetworkCookie &cookie) const
@@ -80,22 +87,22 @@ void PrivacyWebEngineView::addCookieToList(const QNetworkCookie &cookie) const
         CookiesDatabase::updateCookie(cookie);
 
     // Update the cookies action.
-    emit numberOfCookiesChanged(cookieListPointer->size());
+    Q_EMIT numberOfCookiesChanged(cookieListPointer->size());
 }
 
-void PrivacyWebEngineView::applyDomainSettingsWithoutReloading(const QString &hostname)
+void PrivacyWebEngineView::applyDomainSettings(const QUrl &newUrl, const bool navigatingHistory)
 {
-    // Apply the domain settings  `false` does not reload the website.
-    applyDomainSettings(hostname, false);
-}
+    // Store the current host.
+    currentHost = newUrl.host();
 
-void PrivacyWebEngineView::applyDomainSettings(const QString &hostname, const bool reloadWebsite)
-{
-    // Get the record for the hostname.
-    QSqlQuery domainQuery = DomainsDatabase::getDomainQuery(hostname);
+    // Create a user agent changed tracker.
+    bool userAgentChanged = false;
 
-    // Check if the hostname has domain settings.
-    if (domainQuery.isValid())  // The hostname has domain settings.
+    // Get the record for the current host.
+    QSqlQuery domainQuery = DomainsDatabase::getDomainQuery(currentHost);
+
+    // Check if the current host has domain settings.
+    if (domainQuery.isValid())  // The current host has domain settings.
     {
         // Store the domain settings name.
         domainSettingsName = domainQuery.value(DomainsDatabase::DOMAIN_NAME).toString();
@@ -124,8 +131,15 @@ void PrivacyWebEngineView::applyDomainSettings(const QString &hostname, const bo
             case (DomainsDatabase::DISABLED): webEngineSettingsPointer->setAttribute(QWebEngineSettings::LocalStorageEnabled, false); break;
         }
 
-        // Set the user agent.
-        webEngineProfilePointer->setHttpUserAgent(UserAgentHelper::getResultingDomainSettingsUserAgent(domainQuery.value(DomainsDatabase::USER_AGENT).toString()));
+        // Get the domain settings user agent.
+        QString domainSettingsUserAgent = UserAgentHelper::getResultingDomainSettingsUserAgent(domainQuery.value(DomainsDatabase::USER_AGENT).toString());
+
+        // Determine if the user agent is changing.
+        if (webEngineProfilePointer->httpUserAgent() != domainSettingsUserAgent)
+            userAgentChanged = true;
+
+        // Set the user agent.  Setting the user agent, even if it isn't changing, causes the pre-rendered page to enter a locked state where reload doesn't work.
+        webEngineProfilePointer->setHttpUserAgent(domainSettingsUserAgent);
 
         // Set the UltraPrivacy status.
         switch (domainQuery.value(DomainsDatabase::ULTRAPRIVACY).toInt())
@@ -179,7 +193,7 @@ void PrivacyWebEngineView::applyDomainSettings(const QString &hostname, const bo
             defaultZoomFactor = Settings::zoomFactor();
         }
     }
-    else  // The hostname does not have domain settings.
+    else  // The current host does not have domain settings.
     {
         // Reset the domain settings name.
         domainSettingsName = QLatin1String("");
@@ -193,8 +207,15 @@ void PrivacyWebEngineView::applyDomainSettings(const QString &hostname, const bo
         // Set DOM storage.  In QWebEngineSettings it is called Local Storage.
         webEngineSettingsPointer->setAttribute(QWebEngineSettings::LocalStorageEnabled, Settings::domStorageEnabled());
 
-        // Set the user agent.
-        webEngineProfilePointer->setHttpUserAgent(UserAgentHelper::getUserAgentFromDatabaseName(Settings::userAgent()));
+        // Get the default user agent.
+        QString defaultUserAgent = UserAgentHelper::getUserAgentFromDatabaseName(Settings::userAgent());
+
+        // Determine if the user agent is changing.
+        if (webEngineProfilePointer->httpUserAgent() != defaultUserAgent)
+            userAgentChanged = true;
+
+        // Set the user agent.  Setting the user agent, even if it isn't changing, causes the pre-rendered page to enter a locked state where reload doesn't work.
+        webEngineProfilePointer->setHttpUserAgent(defaultUserAgent);
 
         // Set the status for each filter list.
         ultraPrivacyEnabled = Settings::ultraPrivacyEnabled();
@@ -210,15 +231,57 @@ void PrivacyWebEngineView::applyDomainSettings(const QString &hostname, const bo
     // Set the current zoom factor.
     setZoomFactor(defaultZoomFactor);
 
-    // Reload the website if requested.
-    if (reloadWebsite)
-        reload();
-
     // Reset the HTTP authentication dialog counter.
     httpAuthenticationDialogsDisplayed = 0;
 
     // Update the UI.
-    emit updateUi(this);
+    Q_EMIT updateUi(this);
+
+    // Reload the URL.
+    // This works around a bug in Qt WebEngine that causes massive problems when the user agent is changed after the page has started pre-rendering.  <https://redmine.stoutner.com/issues/821>
+    if (navigatingHistory)
+    {
+        // Get a handle for the WebEngine history.
+        QWebEngineHistory *webEngineHistoryPointer = history();
+
+        // Navigate the history according to the status of the user agent.
+        if (userAgentChanged)  // The user agent changed.
+        {
+            // Go back once.  This current navigation will fail, but the next one will succeed.
+            //back();
+
+            if (webEngineHistoryPointer->canGoBack() && (newUrl == webEngineHistoryPointer->backItem().url()))
+            {
+                // Go back twice.  The first one will fail, but the second will succeed.
+                back();
+            }
+            else
+            {
+                // Go forward twice.  The first one will fail, but the second will succeed.
+                forward();
+            }
+        }
+        else  // The user agent did not change.
+        {
+            // The WebEngine history will think it has loaded the final URL, and will be in the correct location, but it will have been interrupted and reloaded the original URL.
+            // The solution is to direct the WebEngine history to offset one and then return, which will actually load the correct URL because `applyDomainSettings` will not be triggered.
+            if (webEngineHistoryPointer->canGoForward())
+            {
+                // Go forward and back one.
+                forward();
+                back();
+            }
+            else
+            {
+                // Go back and forward one.
+                back();
+                forward();
+            }
+        }
+    } else {
+        // Load the new URL again.
+        load(newUrl);
+    }
 }
 
 void PrivacyWebEngineView::clearRequestsList()
@@ -235,15 +298,16 @@ void PrivacyWebEngineView::clearRequestsList()
     requestsListPointer->clear();
 
     // Update the blocked requests action.
-    emit(requestBlocked(blockedRequestsVector));
+    Q_EMIT requestBlocked(blockedRequestsVector);
 }
 
-void PrivacyWebEngineView::contextMenuEvent(QContextMenuEvent *contextMenuEvent) {
-    // Get a handle for the
+void PrivacyWebEngineView::contextMenuEvent(QContextMenuEvent *contextMenuEvent)
+{
+    // Get a handle for the WebEngine page.
     QWebEnginePage *webEnginePagePointer = page();
 
     // Get a handle for the menu.
-    QMenu *contextMenu = webEnginePagePointer->createStandardContextMenu();
+    QMenu *contextMenu = createStandardContextMenu();
 
     // Get the list of context menu actions.
     const QList<QAction *> contextMenuActionsList = contextMenu->actions();
@@ -251,8 +315,14 @@ void PrivacyWebEngineView::contextMenuEvent(QContextMenuEvent *contextMenuEvent)
     // Add the open link in new background tab action if the context menu already contains the open link in new window action.
     if (contextMenuActionsList.contains(webEnginePagePointer->action(QWebEnginePage::OpenLinkInNewWindow)))
     {
+        // Create a manual open in new tab action.
+        QAction *manualOpenLinkInNewTabActionPointer = new QAction(i18nc("Open link in new tab action", "Open link in new tab"), contextMenu);
+
+        // Connect the actions.
+        connect(manualOpenLinkInNewTabActionPointer, SIGNAL(triggered()), this, SLOT(manualOpenInNewTab()));
+
         // Move the open in new tab action above the back action.
-        contextMenu->insertAction(webEnginePagePointer->action(QWebEnginePage::Back), webEnginePagePointer->action(QWebEnginePage::OpenLinkInNewTab));
+        contextMenu->insertAction(webEnginePagePointer->action(QWebEnginePage::Back), manualOpenLinkInNewTabActionPointer);
 
         // Add the open link in background tab action above the back action.
         contextMenu->insertAction(webEnginePagePointer->action(QWebEnginePage::Back), webEnginePagePointer->action(QWebEnginePage::OpenLinkInNewBackgroundTab));
@@ -301,7 +371,8 @@ void PrivacyWebEngineView::contextMenuEvent(QContextMenuEvent *contextMenuEvent)
     contextMenu->popup(contextMenuEvent->globalPos());
 }
 
-QWebEngineView* PrivacyWebEngineView::createWindow(QWebEnginePage::WebWindowType webWindowType) {
+QWebEngineView* PrivacyWebEngineView::createWindow(QWebEnginePage::WebWindowType webWindowType)
+{
     // Get a handle for the browser window.
     BrowserWindow *browserWindowPointer = qobject_cast<BrowserWindow*>(window());
 
@@ -310,9 +381,25 @@ QWebEngineView* PrivacyWebEngineView::createWindow(QWebEnginePage::WebWindowType
     {
         case QWebEnginePage::WebBrowserTab:
         {
-            // Create the new tab and return the privacy WebEngine view pointer.  `true` removes the focus from the blank URL line edit.  `true` adds the new tab adjacent to the current tab.
-            // The new privacy WebEngine view pointer is returned so it can be populated with the link from the context menu.
-            return browserWindowPointer->tabWidgetPointer->addTab(true, true);
+            if (manuallyOpeninginNewTab)
+            {
+                // Reset the manually opening in new tab flag.
+                manuallyOpeninginNewTab = false;
+
+                // Create the new tab and return the privacy WebEngine view pointer.  `true` removes the focus from the blank URL line edit.  `true` adds the new tab adjacent to the current tab.
+                // The new privacy WebEngine view pointer is returned so it can be populated with the link from the context menu.
+                return browserWindowPointer->tabWidgetPointer->addTab(true, true);
+            }
+            else
+            {
+                // The web page is trying to automatically open a new tab by setting the target to be "_blank".  Create a temporary WebEngine view and open it there.
+                // The URL cannot be loaded into this privacy WebEngine view because it will clear the web history.
+                // But the temporary WebEngine will capture the URL and then pass it back to this privacy WebEngine view.
+                TemporaryWebEngineView *temporaryWebEngineViewPointer = new TemporaryWebEngineView(this);
+
+                // Return the temporary WebEngine view.
+                return temporaryWebEngineViewPointer;
+            }
         }
 
         case QWebEnginePage::WebBrowserWindow:
@@ -346,7 +433,7 @@ QWebEngineView* PrivacyWebEngineView::createWindow(QWebEnginePage::WebWindowType
 void PrivacyWebEngineView::displayHttpPingDialog(const QString &httpPingUrl) const
 {
     // Display the HTTP Ping blocked dialog.
-    emit displayHttpPingBlockedDialog(httpPingUrl);
+    Q_EMIT displayHttpPingBlockedDialog(httpPingUrl);
 }
 
 void PrivacyWebEngineView::handleAuthenticationRequest(const QUrl &requestUrl, QAuthenticator *authenticatorPointer)
@@ -364,16 +451,25 @@ void PrivacyWebEngineView::handleAuthenticationRequest(const QUrl &requestUrl, Q
     }
 }
 
+void PrivacyWebEngineView::manualOpenInNewTab()
+{
+    // Set the manually opening in new tab flag.
+    manuallyOpeninginNewTab = true;
+
+    // Open the url in a new tab.
+    triggerPageAction(QWebEnginePage::OpenLinkInNewTab);
+}
+
 void PrivacyWebEngineView::openWithChromium() const
 {
     // Open the current URL in Chromium
-    QProcess::startDetached("chromium", QStringList(hoveredLinkString));
+    QProcess::startDetached(QLatin1String("chromium"), QStringList(hoveredLinkString));
 }
 
 void PrivacyWebEngineView::openWithFirefox() const
 {
     // Open the current URL in Firefox.
-    QProcess::startDetached("firefox-esr", QStringList(hoveredLinkString));
+    QProcess::startDetached(QLatin1String("firefox-esr"), QStringList(hoveredLinkString));
 }
 
 void PrivacyWebEngineView::removeCookieFromList(const QNetworkCookie &cookie) const
@@ -384,7 +480,7 @@ void PrivacyWebEngineView::removeCookieFromList(const QNetworkCookie &cookie) co
     cookieListPointer->remove(cookie);
 
     // Update the cookies action.
-    emit numberOfCookiesChanged(cookieListPointer->size());
+    Q_EMIT numberOfCookiesChanged(cookieListPointer->size());
 }
 
 void PrivacyWebEngineView::saveHoveredLink(const QString &hoveredLink)
@@ -417,6 +513,13 @@ void PrivacyWebEngineView::storeRequest(RequestStruct *requestStructPointer)
         ++blockedRequestsVector[TOTAL];
 
         // Update the blocked requests action.
-        emit(requestBlocked(blockedRequestsVector));
+        Q_EMIT(requestBlocked(blockedRequestsVector));
     }
 }
+
+void PrivacyWebEngineView::storeUpdatedUrl(const QUrl &newUrl)
+{
+    // Store the new URL string (which changes when a new page is loaded as the current URL text.  This is important when loading a new tab from a link.  <https://redmine.stoutner.com/issues/1228>
+    currentUrlText = newUrl.toString();
+}
+
