@@ -1,20 +1,20 @@
-/*
- * Copyright 2022-2024 Soren Stoutner <soren@stoutner.com>.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-FileCopyrightText: 2022-2025 Soren Stoutner <soren@stoutner.com>
  *
  * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc/>.
  *
- * Privacy Browser PC is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
  *
- * Privacy Browser PC is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef PRIVACY_WEBENGINE_VIEW_H
@@ -26,7 +26,7 @@
 // KDE framework headers.
 #include <KLineEdit>
 
-// Qt toolkit headers.
+// Qt framework headers.
 #include <QIcon>
 #include <QList>
 #include <QNetworkCookie>
@@ -53,6 +53,8 @@ public:
     // The public variables.
     QVector<int> blockedRequestsVector = {0, 0, 0, 0, 0, 0};
     std::list<QNetworkCookie> *cookieListPointer = new std::list<QNetworkCookie>;
+    QString currentHost = QLatin1String("");
+    QString currentUrlText = QLatin1String("");
     double defaultZoomFactor = 1.00;
     QString domainSettingsName = QLatin1String("");
     bool easyListEnabled = true;
@@ -70,10 +72,7 @@ public:
     bool ultraListEnabled = true;
     bool ultraPrivacyEnabled = true;
 
-    // The public functions.
-    void applyDomainSettings(const QString &hostname, const bool reloadWebsite);
-
-signals:
+Q_SIGNALS:
     // The signals.
     void numberOfCookiesChanged(const int numberOfCookies) const;
     void displayHttpPingBlockedDialog(const QString &httpPingUrl) const;
@@ -83,22 +82,25 @@ signals:
 public Q_SLOTS:
     // The public slots.
     void addCookieToList(const QNetworkCookie &cookie) const;
+    void applyDomainSettings(const QUrl &newUrl, const bool navigatingHistory);
     void removeCookieFromList(const QNetworkCookie &cookie) const;
 
 private Q_SLOTS:
     // The private slots.
-    void applyDomainSettingsWithoutReloading(const QString &hostname);
     void clearRequestsList();
     void displayHttpPingDialog(const QString &httpPingUrl) const;
     void handleAuthenticationRequest(const QUrl &requestUrl, QAuthenticator *authenticatorPointer);
+    void manualOpenInNewTab();
     void openWithChromium() const;
     void openWithFirefox() const;
     void saveHoveredLink(const QString &hoveredLink);
     void storeRequest(RequestStruct *requestStructPointer);
+    void storeUpdatedUrl(const QUrl &newUrl);
 
 private:
     // The private variables.
     QString hoveredLinkString;
+    bool manuallyOpeninginNewTab = false;
     KLineEdit *passwordLineEditPointer;
     KLineEdit *usernameLineEditPointer;
     QWebEngineProfile *webEngineProfilePointer;
