@@ -1,20 +1,20 @@
-/*
- * Copyright 2022-2024 Soren Stoutner <soren@stoutner.com>.
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-FileCopyrightText: 2022-2024 Soren Stoutner <soren@stoutner.com>
  *
  * This file is part of Privacy Browser PC <https://www.stoutner.com/privacy-browser-pc/>.
  *
- * Privacy Browser PC is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version.
  *
- * Privacy Browser PC is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with Privacy Browser PC.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License along with
+ * this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef BROWSER_WINDOW_H
@@ -52,11 +52,13 @@ public:
 
 public Q_SLOTS:
     // The public slots.
+    void applyDomainSettingsInThisWindow();  // This is public so that the domain settings can be reapplied over D-Bus when changed by another instance of Privacy Browser.
     void populateBookmarksInThisWindow();  // This is public so that the bookmarks can be repopulated over D-Bus when changed by another instance of Privacy Browser.
 
 private Q_SLOTS:
     // The private slots.
     void addOrEditDomainSettings();
+    void applyDomainSettingsInAllWindows() const;
     void back() const;
     void clearUrlLineEditFocus() const;
     void decrementZoom();
@@ -76,8 +78,11 @@ private Q_SLOTS:
     void openWithChromium() const;
     void openWithFirefox() const;
     void populateBookmarksInAllWindows() const;
+    void processUrlTextChanges(const QString &newUrlText) const;
     void refresh() const;
     void reloadAndBypassCache() const;
+    void restoreUrlText() const;
+    void runMethodInAllWindows(const QString &methodString) const;
     void showBookmarkContextMenu(const QPoint &point);
     void showCookiesDialog();
     void showDomainSettingsDialog();
@@ -137,6 +142,7 @@ private:
     double defaultZoomFactorDouble;
     QAction *developerToolsActionPointer;
     QAction *domStorageActionPointer;
+    bool domainSettingsApplied = false;
     QAction *easyPrivacyActionPointer;
     QAction *easyListActionPointer;
     QAction *fanboysAnnoyanceListPointer;
@@ -160,6 +166,7 @@ private:
     QProgressBar *progressBarPointer;
     QAction *refreshActionPointer;
     QAction *requestsActionPointer;
+    QAction *restoreUrlTextActionPointer;
     QAction *searchEngineMenuActionPointer;
     QAction *searchEngineMojeekActionPointer;
     QAction *searchEngineMonoclesActionPointer;
